<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
 * Analytics petition views chart js
 *
 * @since Campoal Tapo 1.6.0
 */
if (!function_exists('conikal_petition_visitors_chart_js')) :    
    function conikal_petition_visitors_chart_js() {
        check_ajax_referer('dashboard_petition_ajax_nonce', 'security');
        global $campoal_options;
        $main_color = isset($campoal_options['conikal_main_color_field']) ? $campoal_options['conikal_main_color_field'] : '';
        $chart_color_1 = isset($campoal_options['conikal_chart_color_1_field']) ? $campoal_options['conikal_chart_color_1_field'] : '';
        $chart_color_2 = isset($campoal_options['conikal_chart_color_2_field']) ? $campoal_options['conikal_chart_color_2_field'] : '';

        $id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
        $date_range = isset($_POST['date_range']) ? sanitize_text_field($_POST['date_range']) : 14;
        $date_start = isset($_POST['date_start']) ? sanitize_text_field($_POST['date_start']) : false;
        $date_end = isset($_POST['date_end']) ? sanitize_text_field($_POST['date_end']) : false;
        $post_type = get_post_type($id);

        // Check ID exits or not
        if ($id) {

            // count view on date
            $viewers_list = get_post_meta($id, 'post_visitors_list', true);
            $views_chart = conikal_petition_dataset_calculator($viewers_list, $date_range, $date_start, $date_end);

            $players_list = get_post_meta($id, 'post_players_list', true);
            $players_chart = conikal_petition_dataset_calculator($players_list, $date_range, $date_start, $date_end);

            // conversion view to play
            $conversions_chart = array();
            foreach ($views_chart->data as $key => $views) {
                if (!empty($players_chart)) {
                    $players = (array_key_exists($key, $players_chart->data) ? $players_chart->data[$key] : 0);
                } else {
                    $players = 0;
                }

                if (intval($views) != 0 && intval($players) != 0) {
                    $conversion = (intval($players) / intval($views)) * 100;
                    $conversion = round($conversion, 0);
                } else {
                    $conversion = 0;
                }

                array_push($conversions_chart, $conversion);
            }

            // echo chart data
            echo json_encode(array(
                'status' => 1,
                'colors' => array(
                    'main_color'    => esc_html($main_color),
                    'chart_color_1' => esc_html($chart_color_1),
                    'chart_color_2' => esc_html($chart_color_2),
                ),
                'visitors_date' => $views_chart->date,
                'visitors_data' => $views_chart->data,
                'visitors_title' => esc_html__('Visitors', 'campoal-tapo'),
                'players_date' => $players_chart->date,
                'players_data' => $players_chart->data,
                'players_title' => esc_html__('Video Viewers', 'campoal-tapo'),
                'conversion_title' => esc_html__('Conversion (%)', 'campoal-tapo'),
                'conversions_data' => $conversions_chart,
            ));
            exit();
        } else {
            echo json_encode(array('status' => 0));
            exit();
        }
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_petition_visitors_chart_js', 'conikal_petition_visitors_chart_js' );
add_action( 'wp_ajax_conikal_petition_visitors_chart_js', 'conikal_petition_visitors_chart_js' );


/**
 * Get users visitor by IP
 *
 * @since Campoal Tapo 1.6.0
 */
if (!function_exists('conikal_petition_users_visitors')) :    
    function conikal_petition_users_visitors() {
        check_ajax_referer('dashboard_petition_ajax_nonce', 'security');

        $id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : '';
        $paged = isset($_POST['paged']) ? sanitize_text_field($_POST['paged']) : 1;
        $post_type = get_post_type($id);

        // lazy load placeholder
        $lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

        $visitors = get_post_meta($id, 'post_visitors_list', true);
        $visitors_list = ($visitors ? array_keys($visitors) : 0);
        $players = get_post_meta($id, 'post_players_list', true);
        $players_list = ($players ? array_keys($players) : 0);

        $args = array(
            'orderby' => 'registered',
            'order' => 'DESC',
            'number' => 15,
            'paged' => $paged,
            'fields'  => array(
                'ID',
                'display_name',
                'user_login',
            )
        );

        $args['meta_query'] = array('relation' => 'AND');

        array_push($args['meta_query'], array(
            'key'     => 'signup_ip',
            'value'   => ($type == 'visitors' ? $visitors_list : $players_list),
            'compare' => 'IN',
            'type'    => 'CHAR',
        ));

        $users_visit = new WP_User_Query( $args );

        $recent_visitors = array();
        if ( $users_visit ) :
            foreach ($users_visit->get_results() as $user) {
                $user_id            = $user->ID;
                $user_name          = $user->display_name;
                $user_address       = get_user_meta($user_id, 'user_address', true);
                $user_neigborhood   = get_user_meta($user_id, 'user_neigborhood', true);
                $user_city          = get_user_meta($user_id, 'user_city', true);
                $user_state         = get_user_meta($user_id, 'user_state', true);
                $user_country       = get_user_meta($user_id, 'user_country', true);
                $user_avatar        = conikal_get_avatar_url( $user_id, array('size' => 64) );
                $user_avatar_retina = conikal_get_avatar_url( $user_id, array('size' => 128) );
                $user_link          = get_author_posts_url($user_id);
                $user_ip            = get_user_meta($user_id, 'signup_ip', true);
                $visit_date         = ($type == 'visitors' ? $visitors[$user_ip]['date'] : $players[$user_ip]['date']);
                $visit_time         = strtotime($visit_date, current_time('timestamp'));
                $visit_time         = sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff($visit_time, current_time('timestamp')));

                $recent_visitor = array(
                    'user_id'               => esc_html($user_id),
                    'user_name'             => esc_html($user_name),
                    'user_address'          => esc_html($user_address),
                    'user_neigborhood'      => esc_html($user_neigborhood),
                    'user_city'             => esc_html($user_city),
                    'user_state'            => esc_html($user_state),
                    'user_country'          => esc_html($user_country),
                    'user_avatar'           => esc_url($user_avatar),
                    'user_avatar_retina'    => esc_url($user_avatar_retina),
                    'user_avatar_lazy'      => esc_url($lazy_placeholder_avatar),
                    'user_link'             => esc_url($user_link),
                    'user_ip'               => (current_user_can('editor') || current_user_can('administrator') ? esc_html($user_ip) : ''),
                    'visit_time'            => esc_html($visit_time),
                );

                array_push($recent_visitors, $recent_visitor);
            }
        endif;

        if (!empty($recent_visitors)) {
            echo json_encode(array( 'status' => 1, 'users' => $recent_visitors, 'total' => $users_visit->get_total() ));
            exit();
        } else {
            echo json_encode(array('status' => 0, 'ip' => $visitors_list));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_petition_users_visitors', 'conikal_petition_users_visitors' );
add_action( 'wp_ajax_conikal_petition_users_visitors', 'conikal_petition_users_visitors' );


/**
 * Analytics petition chart js
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_petition_chart_js')) :    
    function conikal_petition_chart_js() {
        check_ajax_referer('dashboard_petition_ajax_nonce', 'security');
        global $campoal_options;
        $main_color = isset($campoal_options['conikal_main_color_field']) ? $campoal_options['conikal_main_color_field'] : '';
        $chart_color_1 = isset($campoal_options['conikal_chart_color_1_field']) ? $campoal_options['conikal_chart_color_1_field'] : '';
        $chart_color_2 = isset($campoal_options['conikal_chart_color_2_field']) ? $campoal_options['conikal_chart_color_2_field'] : '';

        $id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : '';
        $date_range = isset($_POST['date_range']) ? sanitize_text_field($_POST['date_range']) : 14;
        $date_start = isset($_POST['date_start']) ? sanitize_text_field($_POST['date_start']) : false;
        $date_end = isset($_POST['date_end']) ? sanitize_text_field($_POST['date_end']) : false;
        $post_type = get_post_type($id);

        // Check ID exits or not
        if ($id) {
            $users_gender = array();
            $users_age = array();
            $users_regions = array();

            // get supporter
            $supporters = array();
            if ($post_type == 'petition') {
                $supporters = get_post_meta($id, 'petition_users', true);
                $supporters = array_reverse($supporters);
            } else if (class_exists('Give') ) {
                if (function_exists('give_get_payments')) {
	                $args = array(
	                	'status'     => 'publish',
	                    'give_forms' => array($id),
	                    'order' => 'DESC'
	                );
	                $donations = give_get_payments( $args );

	                foreach($donations as $donation) {
                        $customer_id            = give_get_payment_donor_id( $donation->ID );
                        $customer               = new Give_Customer( $customer_id );
                        $payment    			= new Give_Payment( $donation->ID );
                        $payment_date 			= $payment->date;

                        array_push($supporters, array('id' => $customer->id, 'user_id' => $customer->user_id, 'name' => $customer->name, 'date' => $payment_date));
                    }
	            }
            } 
            
            // get recent supporters
            $recent_supporters = array();

            // lazy load placeholder
            $lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

            // calculating data for chart
            $i = 0;
            foreach ($supporters as $supporter) {
                $user = get_user_by('ID', $supporter['user_id']);
                if($user) {
                    $user_id = $user->ID;
                    $user_city = get_user_meta($user_id, 'user_city', true);
                    $user_state = get_user_meta($user_id, 'user_state', true);
                    $user_country = get_user_meta($user_id, 'user_country', true);
                    $user_gender = get_user_meta($user_id, 'user_gender', true);
                    $user_birthday = get_user_meta($user_id, 'user_birthday', true);
                    $user_birthday = $user_birthday ? date_i18n('m/d/Y', strtotime($user_birthday)) : false;

                    // get 20 user recent sign
                    if ($i < 20) {
                        $user_name          = $user->display_name;
                        $user_address       = get_user_meta($user_id, 'user_address', true);
                        $user_neigborhood   = get_user_meta($user_id, 'user_neigborhood', true);
                        $user_city          = get_user_meta($user_id, 'user_city', true);
                        $user_state         = get_user_meta($user_id, 'user_state', true);
                        $user_country       = get_user_meta($user_id, 'user_country', true);
                        $user_avatar        = conikal_get_avatar_url( $user_id, array('size' => 64) );
                        $user_avatar_retina = conikal_get_avatar_url( $user_id, array('size' => 128) );
                        $user_link          = get_author_posts_url($user_id);
                        $sign_date          = strtotime($supporter['date'], current_time('timestamp'));
                        $sign_date          = sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff($sign_date, current_time('timestamp')));

                        $recent_supporter = array(
                            'user_name'             => esc_html($user_name),
                            'user_address'          => esc_html($user_address),
                            'user_neigborhood'      => esc_html($user_neigborhood),
                            'user_city'             => esc_html($user_city),
                            'user_state'            => esc_html($user_state),
                            'user_country'          => esc_html($user_country),
                            'user_avatar'           => esc_url($user_avatar),
                            'user_avatar_retina'    => esc_url($user_avatar_retina),
                            'user_avatar_lazy'      => esc_url($lazy_placeholder_avatar),
                            'user_link'             => esc_url($user_link),
                            'sign_date'             => esc_html($sign_date),
                        );
                        array_push($recent_supporters, $recent_supporter);
                        $i++;
                    }


                    // add gender by type
                    if ( $user_gender === 'male' ) {
                        array_push($users_gender, 'male');
                    } elseif ( $user_gender === 'famale' ) {
                        array_push($users_gender, 'famale');
                    } else {
                        array_push($users_gender, 'unknown');
                    }

                    // add age by segment
                    if ($user_birthday) {
                        $user_age = conikal_get_age($user_birthday);
                        if ($user_age <= 17) {
                            array_push($users_age, '13');
                        } elseif ($user_age >= 18 && $user_age <= 24) {
                            array_push($users_age, '18');
                        } elseif ($user_age >= 25 && $user_age <= 34 ) {
                            array_push($users_age, '25');
                        } elseif ($user_age >= 35 && $user_age <= 44) {
                            array_push($users_age, '35');
                        } elseif ($user_age >= 45 && $user_age <= 54) {
                            array_push($users_age, '45');
                        } elseif ($user_age >= 55 && $user_age <= 64) {
                            array_push($users_age, '55');
                        } elseif ($user_age >= 65) {
                            array_push($users_age, '65');
                        }
                    }

                    if ($user_country != '') {
                        array_push($users_regions, $user_country);
                    } else {
                        array_push($users_regions, 'NO');
                    }
                }
            }

            // SUPPORTERS COLUMN CHART
            $sign_users = get_post_meta($id, 'petition_users', true);
            $chart_data = conikal_petition_dataset_calculator($sign_users, $date_range, $date_start, $date_end);

            // CALCULAR PERCENT FOR REGIONS
            $regionsData = array();
            $users_regions = array_count_values($users_regions);
            arsort($users_regions);

            // add resion labels
            $regions_labels = array();
            foreach ($users_regions as $name => $count) {
                array_push($regions_labels, $name);
            }

            // total of supporter have region
            $totalRegions = 0;
            foreach ($users_regions as $region) {
                $totalRegions = $totalRegions + (int)$region;
            }

            // divi percent per region
            if ($totalRegions > 0) {
                foreach ($users_regions as $region) {
                    if ($region != 0) {
                        $percent = ((int)$region / $totalRegions) * 100;
                        $percent = round($percent, 0);
                    } else {
                        $percent = 0;
                    }
                    array_push($regionsData, $percent);
                }
            }

            // convert region array to json
            $regionsData = isset($regionsData) ? $regionsData : '[0,0,0,0,0,0,0]';

            // CALCULAR PERCENT FOR GENDER
            $users_gender = array_count_values($users_gender);
            if (!array_key_exists('male', $users_gender)) {
                $users_gender['male'] = 0;
            } elseif (!array_key_exists('famale', $users_gender)) {
                $users_gender['famale'] = 0;
            } elseif (!array_key_exists('unknown', $users_gender)) {
                $users_gender['unknown'] = 0;
            }
            ksort($users_gender);
            $genderData = array();

            // total of supporter have gender
            $totalGender = 0;
            foreach ($users_gender as $gender) {
                $totalGender = $totalGender + (int)$gender;
            }

            // divi percent per gender
            if ($totalGender > 0) {
                foreach ($users_gender as $gender) {
                    if ($gender != 0) {
                        $percent = ((int)$gender / $totalGender) * 100;
                        $percent = round($percent, 0);
                    } else {
                        $percent = 0;
                    }
                    array_push($genderData, $percent);
                }
            }

            // convert gender array to json
            $genderData = isset($genderData) ? $genderData : "[0,0,0]";

            $genderLabels = array(
                esc_html__('Famale (%)', 'campoal-tapo'),
                esc_html__('Male (%)', 'campoal-tapo'),
                esc_html__('Unknown (%)', 'campoal-tapo')
            );

            // CALCULAR PERCENT FOR AGE
            $users_age = array_count_values($users_age);
            for ($i=1; $i<=7; $i++) {
                if (!array_key_exists('13', $users_age)) {
                    $users_age['13'] = 0;
                } elseif (!array_key_exists('18', $users_age)) {
                    $users_age['18'] = 0;
                } elseif (!array_key_exists('25', $users_age)) {
                    $users_age['25'] = 0;
                } elseif (!array_key_exists('35', $users_age)) {
                    $users_age['35'] = 0;
                } elseif (!array_key_exists('45', $users_age)) {
                    $users_age['45'] = 0;
                } elseif (!array_key_exists('55', $users_age)) {
                    $users_age['55'] = 0;
                } elseif (!array_key_exists('65', $users_age)) {
                    $users_age['65'] = 0;
                }
            }
            ksort($users_age);
            $ageData = array();

            // total of supporter have age
            $totalAge = 0;
            foreach ($users_age as $age) {
                $totalAge = $totalAge + (int)$age;
            }

            // divi percent per age
            if ($totalAge > 0) {
                foreach ($users_age as $age) {
                    if ($age != 0) {
                        $percent = ((int)$age / $totalAge) * 100;
                        $percent = round($percent, 0);
                    } else {
                        $percent = 0;
                    }
                    array_push($ageData, $percent);
                }
            }

            // convert age array to json
            $ageData = isset($ageData) ? $ageData : array(0, 0, 0, 0, 0, 0, 0);
            $age_labels = array('13-17', '18-24', '25-34', '35-44', '45-54', '55-65', '65+');

            echo json_encode(array(
                'status' => 1,
                'colors' => array(
                    'main_color'    => esc_html($main_color),
                    'chart_color_1' => esc_html($chart_color_1),
                    'chart_color_2' => esc_html($chart_color_2),
                ),
                'supporter_date' => $chart_data->date,
                'supporter_data' => $chart_data->data,
                'supporter_title' => esc_html__('Supporters', 'campoal-tapo'),
                'regions_labels' => $regions_labels,
                'regions_data' => $regionsData,
                'regions_title' => esc_html__('Country (%)', 'campoal-tapo'),
                'gender_labels' => $genderLabels,
                'gender_data' => $genderData,
                'gender_title' => esc_html__('Gender (%)', 'campoal-tapo'),
                'age_labels' => $age_labels,
                'age_data'  => $ageData,
                'age_title' => esc_html__('Age (%)', 'campoal-tapo'),
                'recent_supporters' => $recent_supporters,
            ));
            exit();
        } else {
            echo json_encode(array('status' => 0));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_petition_chart_js', 'conikal_petition_chart_js' );
add_action( 'wp_ajax_conikal_petition_chart_js', 'conikal_petition_chart_js' );


/**
 * Petition chart dataset calculator
 *
 * @since Campoal Tapo 1.6.0
 */
if (!function_exists('conikal_petition_dataset_calculator')) :    
    function conikal_petition_dataset_calculator($dataset, $date_range = 14, $date_start = false, $date_end = false) {
        if (empty($dataset)) {
            $dataset = array();
        }

        if (!empty($date_start) && !empty($date_end)) {
            $date_range = conikal_date_difference($date_start, $date_end);
            $date_start = strtotime($date_start);
            $date_end   = strtotime($date_end);
        } else {
            $date_end = strtotime(current_time('mysql')); 
        }

        // value of date label
        $date_range = intval($date_range);
        if ($date_range <= 30) {
            $date_compare_value = 'd';
            $date_label_value = 'd';
        } else if($date_range > 30 && $date_range < 360) {
            $date_compare_value = 'W';
            $date_label_value = 'm/d';
        } else if ($date_range >= 360) {
            $date_compare_value = 'm';
            $date_label_value = 'm';
        } else {
            $date_compare_value = 'm/d';
        }

        //echo $date_range . ' - ' . $date_compare_value;

        // create array of date
        $arrDate = array();
        for ($i=0; $i <= $date_range; $i++) { 
            $date_start = strtotime('-' . $i . ' day', $date_end);
            if ( date('Y', $date_start) == date('Y', $date_end) ) {
                array_push($arrDate, date($date_compare_value, $date_start));
            }
            $date_start = strtotime(current_time('mysql'));
        }

        // count view on date
        $viewsDate = array();
        foreach ($dataset as $user) {
            $user_date = $date = strtotime($user['date']);
            $user_date = date($date_compare_value, $user_date);
            array_push($viewsDate, $user_date);
        }
        $viewsDate = array_count_values($viewsDate);

        $chartData = array();
        $chartDate = array();
        $totalData = array();

        // set views count to the date
        foreach ($viewsDate as $view_date => $view_count) {
            if ( in_array($view_date, $arrDate) ) {
                $totalData[$view_date] = $view_count;
            }
        }

        // set zero if not view in the date
        foreach ($arrDate as $date) {
            if ( !array_key_exists($date, $totalData) ) {
                $totalData[$date] = 0;
            }
        }

        ksort($totalData);
        foreach ($totalData as $date => $count) {
            array_push($chartData, $count);

            // format date label
            if ($date_compare_value != 'W') {
                $date = date_create_from_format($date_compare_value . ' Y', strval($date) . ' ' . strval(date('Y', strtotime(current_time('mysql')))) );
                $formated_date = date_format($date, $date_label_value);
            } else {
                $formated_date = new DateTime();
                $formated_date->setISODate( date('Y', strtotime(current_time('mysql'))), $date );
                $formated_date = $formated_date->format($date_label_value);
            }

            array_push($chartDate, $formated_date);
        }

        $results = array(
            'date' => $chartDate,
            'data' => $chartData
        );

        return (object) $results;
    }
endif;

/**
 * Function to get two date difference.
 *
 * @since Campoal Tapo 1.6.0
 */
if (!function_exists('conikal_date_difference')) :    
    function conikal_date_difference($date_start , $date_end , $format_diff = '%a' ) {
        $create_date_start = date_create($date_start);
        $create_date_end = date_create($date_end);
       
        $interval = date_diff($create_date_start, $create_date_end);
       
        return $interval->format($format_diff);
    }
endif;
?>