<?php 
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
 * Save new petition
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_api_search_petitions')) :
    function conikal_api_search_petitions() {
        global $campoal_options;

        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;
        $search_result_page = isset($campoal_options['conikal_page_petitions_search_results_field']) ? $campoal_options['conikal_page_petitions_search_results_field'] : 0;
        $search_result_page = ($search_result_page ? get_permalink($search_result_page) : '');
        $posts_per_page_setting = isset($campoal_options['conikal_petitions_per_page_field']) ? $campoal_options['conikal_petitions_per_page_field'] : '';
        $posts_per_page = $posts_per_page_setting != '' ? $posts_per_page_setting : 10;

        $keyword = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';

        $args = array(
            'post_type' => 'petition',
            'posts_per_page' => $posts_per_page,
            'paged' => 1,
            'post_status' => array('publish'),
            's' => $keyword
        );
        $args['meta_query'] = array('relation' => 'AND');

        if ($minimum_signature != 0) {
            array_push($args['meta_query'], array(
                'key'     => 'petition_sign',
                'value'   => $minimum_signature,
                'type'    => 'NUMERIC',
                'compare' => '>='
            ));
        }

        $petitions = new WP_Query($args);

        wp_reset_query();
        wp_reset_postdata();

        // processing query and get meta post.
        $arrayPetitions = conikal_process_petition_query($petitions);

        if ($arrayPetitions) {
            echo json_encode(array(
                'status' => true, 
                'total' => $petitions->found_posts, 
                'results' => $arrayPetitions, 
                'message' => esc_html__('Petitions was loaded successfully.', 'campoal-tapo'), 
                'action' => array('url' => ($search_result_page ? esc_url($search_result_page . '?q=' . $keyword) : ''), 
                'text' => sprintf( _n('View %1$s result for “%2$s“', 'View %1$s results for “%2$s“', $petitions->found_posts, 'campoal-tapo'), $petitions->found_posts, $keyword ),
            ) ));
            exit();
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. Not found petitions.', 'campoal-tapo')));
            exit();
        }
    }
endif;


/**
 * Search decistion makers
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_api_search_decisionmakers')) :
    function conikal_api_search_decisionmakers() {
        $keyword = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';

        $args = array(
            'post_type' => 'decisionmakers',
            'posts_per_page' => -1,
            'post_status' => array('publish'),
            's' => $keyword
        );

        $decisionmakers = new WP_Query($args);

        $arrayDecisionmakers = array();
        if($decisionmakers->have_posts()) {
            while ( $decisionmakers->have_posts() ) {
                $decisionmakers->the_post();

                $id                 = get_the_ID();
                $link               = get_permalink($id);
                $name               = get_the_title($id);
                $title              = wp_get_post_terms($id, 'decisionmakers_title', true);
                $title_name         = ($title ? $title[0]->name : '');
                $organization       = wp_get_post_terms($id, 'decisionmakers_organization', true);
                $organization_name  = ($organization ? $organization[0]->name : '');
                $excerpt            = conikal_get_excerpt_by_id($id);
                $author             = get_the_author_meta('ID');
                $avatar             = conikal_get_avatar_url( $author, array('size' => 64) );
                $avatar_retina      = conikal_get_avatar_url( $author, array('size' => 128) );
                $description        = sprintf(esc_html__('%1$s of %2$s', 'campoal-tapo'), $title_name, $organization_name);

                $arrayDecision = array(
                        'id'            => $id, 
                        'link'          => $link,
                        'name'          => $name,
                        'title'         => $title_name,
                        'organization'  => $organization_name,
                        'description'   => $description,
                        'excerpt'       => $excerpt,
                        'avatar'        => $avatar,
                        'avatar_retina' => $avatar_retina,
                        'author'        => $author,
                    );

                $arrayDecision = (object) $arrayDecision;
                array_push($arrayDecisionmakers, $arrayDecision);
            }
        }

        wp_reset_query();
        wp_reset_postdata();

        if ($arrayDecisionmakers) {
            echo json_encode(array('status' => true, 'total' => $decisionmakers->found_posts, 'results' => $arrayDecisionmakers, 'message' => esc_html__('Petitions was loaded successfully.', 'campoal-tapo') ));
            exit();
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. Not found petitions.', 'campoal-tapo')));
            exit();
        }
    }
endif;

/**
 * Search organization and position
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_api_search_organizations_position')) :
    function conikal_api_search_organizations_position($type_taxonomies = 'decisionmakers_organization') {
        global $campoal_options;

        $keyword = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';

        $type_args = array(
            'orderby'           => 'name', 
            'order'             => 'ASC',
            'hide_empty'        => false,
            'search'            => $keyword
        );
        $type_terms = get_terms($type_taxonomies, $type_args);
        $topics = array();
        $topics['results'] = array();

        if ($type_terms) {
            $topics['topics'] = true;
            $count = 0;
            foreach ($type_terms as $type_term) {
                array_push($topics['results'], array('name' => $type_term->name, 'value' => $type_term->name));
            }
            echo json_encode($topics);
            exit();
        } else {
            echo json_encode(array('topics'=>false, 'message'=>esc_html__('Not found topics.', 'campoal-tapo')));
            exit();
        }
    }
endif;


/**
 * Search petition topcis
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_api_search_topics')) :
    function conikal_api_search_topics($taxonomies_name = 'petition_topics') {
        global $campoal_options;

        $keyword = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';

        $type_taxonomies = array( 
            $taxonomies_name
        );
        $type_args = array(
            'orderby'           => 'name', 
            'order'             => 'ASC',
            'hide_empty'        => false,
            'search'            => $keyword
        );
        $type_terms = get_terms($type_taxonomies, $type_args);
        $topics = array();
        $topics['results'] = array();

        if ($type_terms) {
            $topics['topics'] = true;
            $count = 0;
            foreach ($type_terms as $type_term) {
                array_push($topics['results'], array('name' => $type_term->name, 'value' => $type_term->name));
            }
            echo json_encode($topics);
            exit();
        } else {
            echo json_encode(array('topics'=>false, 'message'=>__('Not found topics.', 'campoal-tapo')));
            exit();
        }
    }
endif;

?>