<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
 * Add new comment and signature pettion
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_comments') ): 
    function conikal_add_comments() {
        check_ajax_referer('comment_ajax_nonce', 'security');

        global $campoal_options;
        $recaptcha_comment = isset($campoal_options['conikal_google_recaptcha_comment_field']) ? $campoal_options['conikal_google_recaptcha_comment_field'] : 1;

        $allowed_html       = conikal_content_allowed_html();
        $post_id            = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id            = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $fullname           = isset($_POST['fullname']) ? sanitize_text_field($_POST['fullname']) : '';
        $email              = isset($_POST['email']) ? sanitize_text_field($_POST['email']) : '';
        $cookies_consent    = isset($_POST['cookies_consent']) ? sanitize_text_field($_POST['cookies_consent']) : 'false';
        $content            = isset($_POST['content']) ? wp_kses($_POST['content'], $allowed_html) : '';
        $parent             = isset($_POST['parent']) ? sanitize_text_field($_POST['parent']) : 0;
        $anonymous          = isset($_POST['anonymous']) ? sanitize_text_field($_POST['anonymous']) : 0;
        $author             = !empty($user_id) ? get_userdata($user_id) : 0;

        // Get comment options
        $moderation         = get_option('comment_moderation');
        $comments_notify    = get_option('comments_notify');
        $moderation_notify  = get_option('moderation_notify');
        // $ip_address = conikal_get_client_ip();


        // Check validate fields
        if ($content == '') {
            echo json_encode(array('status' => false, 'message' => esc_html__('Comment content is required!', 'campoal-tapo')));
            exit();
        }

        if ($fullname == '' && empty($user_id)) {
            echo json_encode(array('status' => false, 'message' => esc_html__('Your fullname is required!', 'campoal-tapo')));
            exit();
        }

        if ($email == '' && empty($user_id)) {
            echo json_encode(array('status' => false, 'message' => esc_html__('Your email is required!', 'campoal-tapo')));
            exit();
        }

        if (!is_email($email) && empty($user_id)) {
            echo json_encode(array('status' => false, 'message' => esc_html__('Your email must be correct format!', 'campoal-tapo')));
            exit();
        }

        // Vertify Google reCAPTCHA
        if (!$author && conikal_show_google_reCaptcha() && $recaptcha_comment == 1) {
            conikal_google_recaptcha_callback();
        }

        // Comment data insert
        $comment_data = array(
            'comment_post_ID' => $post_id,
            'comment_author' => (!empty($user_id) ? $author->user_login : $fullname),
            'comment_author_email' => (!empty($user_id) ? $author->user_email : $email),
            'comment_author_url' => (!empty($user_id) ? $author->user_url : ''),
            'comment_content' => $content,
            'comment_type' => '',
            'comment_parent' => $parent,
            'user_id' => (!empty($user_id) ? $user_id : ''),
        );

        // Add new comment and get comment just added
        $comment_id = wp_new_comment($comment_data);
        $details = get_comment($comment_id);

        // Set comment cookies conset
        if (empty($user_id)) {
            $cookies_consent = $cookies_consent == 'true' ? true : false;
            conikal_set_comment_cookies($details, $cookies_consent);
        }

        // set anonymouse comment
        update_comment_meta($comment_id, 'comment_anonymous', $anonymous);

        // get user data
        $author_data   = get_userdata($details->user_id);
        
        // change author by display name if user is exist
        if (!$author_data) {
            $author_name = $details->comment_author;
            $details->comment_author_name = $author_name;
        } else {
            $author_name   = $author_data->display_name;
        }

        // get author avatar
        $author_avatar = conikal_get_avatar_url( ($user_id != 0 ? $author->ID : 0), array('size' => 64) );
        $details->comment_author_avatar = $author_avatar;
                
        // update comment details
        $details->comment_author_name = $author_name;
        $details->comment_author_avatar = $author_avatar;
        $details->comment_author_link = get_author_posts_url($details->user_id);
        $details->comment_content = wpautop($details->comment_content);
        if ($comment_id != 0) {
            echo json_encode(array('status' => true, 'id' => $comment_id, 'time' => esc_html__(' just now', 'campoal-tapo'), 'details' => $details, 'message' => esc_html__('The comment was successfuly saved', 'campoal-tapo')));

            if ( function_exists('conikal_admin_new_comment_notification') ) {
                if ( $comments_notify == 1 ) {
                    conikal_admin_new_comment_notification($post_id, $comment_id);
                } elseif ( $moderation_notify == 1 && $moderation == 1 ) {
                    conikal_admin_new_comment_notification($post_id, $comment_id);
                }
            }

            exit();
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. The comment was not saved.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_add_comments', 'conikal_add_comments' );
add_action( 'wp_ajax_conikal_add_comments', 'conikal_add_comments' );


/**
 * Upvote and downvote commment
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_vote_comment') ): 
    function conikal_vote_comment() {
        check_ajax_referer('comment_ajax_nonce', 'security');

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $comment_id = isset($_POST['comment_id']) ? sanitize_text_field($_POST['comment_id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : '';


        $vote_key = 'comment_vote';
        $vote = get_comment_meta($comment_id, $vote_key, true);

        if ($type == 'up') {
            if($vote == '') {
                $vote = array();
                delete_user_meta($comment_id, $vote_key);
                add_comment_meta($comment_id, $vote_key, $vote);
            }
            if(in_array($user_id, $vote) === false) {
                array_push($vote, $user_id);
                update_comment_meta($comment_id, $vote_key, $vote);
            }

            echo json_encode(array('status' => true, 'type' => $type, 'votes' => $vote));
            exit();
        } elseif ($type == 'down') {
            if(in_array($user_id, $vote)) {
                $vote = array_diff($vote, array($user_id));
                update_comment_meta($comment_id, $vote_key, $vote);
            }

            echo json_encode(array('status' => true, 'type' => $type, 'votes' => $vote));
            exit();
        }
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_vote_comment', 'conikal_vote_comment' );
add_action( 'wp_ajax_conikal_vote_comment', 'conikal_vote_comment' );


/**
 * Save update comment
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_update_comment') ): 
    function conikal_update_comment() {
        check_ajax_referer('comment_ajax_nonce', 'security');

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $comment_id = isset($_POST['comment_id']) ? sanitize_text_field($_POST['comment_id']) : '';
        $content = isset($_POST['content']) ? sanitize_textarea_field($_POST['content']) : '';

        if ($content == '') {
            echo json_encode(array('status' => false, 'message' => esc_html__('Comment content is required!', 'campoal-tapo')));
            exit();
        }

        $arg = array(
                'comment_ID' => $comment_id,
                'comment_content' => $content
            );
        $update_comment = wp_update_comment($arg);

        $content = wpautop($content);

        if ($update_comment) {
            echo json_encode(array('status' => true, 'id' => $comment_id, 'content' => $content, 'message' => esc_html__('Update comment successfuly.', 'campoal-tapo') ));
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. Comment is not update.', 'campoal-tapo') ));
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_update_comment', 'conikal_update_comment' );
add_action( 'wp_ajax_conikal_update_comment', 'conikal_update_comment' );


/**
 * Delete comment
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_delete_comment') ): 
    function conikal_delete_comment() {
        check_ajax_referer('comment_ajax_nonce', 'security');

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $comment_id = isset($_POST['comment_id']) ? sanitize_text_field($_POST['comment_id']) : '';

        $delete_comment = wp_delete_comment($comment_id);

        if ($delete_comment == true) {
            echo json_encode(array('status' => true, 'id' => $comment_id, 'message' => esc_html__('The comment was deleted successfuly.', 'campoal-tapo') ));
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. Comment is not update.', 'campoal-tapo') ));
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_delete_comment', 'conikal_delete_comment' );
add_action( 'wp_ajax_conikal_delete_comment', 'conikal_delete_comment' );


/**
 * Add comment while sign petition as guest
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_comment_sign') ): 
    function conikal_add_comment_sign($user_id, $post_id, $content, $anonymous = 0) {

        $ip_address = conikal_get_client_ip();
        $author  = get_userdata( $user_id );
        $moderation = get_option('comment_moderation');

        if ($content == '') {
            echo json_encode(array('status' => false, 'message' => esc_html__('Comement content is required!', 'campoal-tapo')));
            exit();
        }

        $comment_data = array(
            'comment_post_ID' => $post_id,
            'comment_author' => $author->user_login,
            'comment_author_email' => $author->user_email,
            'comment_author_url' => $author->user_url,
            'comment_content' => $content,
            'comment_type' => '',
            'comment_parent' => 0,
            'user_id' => $user_id,
        );

        $comment_id = wp_new_comment($comment_data);
        $details = get_comment($comment_id);

        // set anonymouse comment
        update_comment_meta($comment_id, 'comment_anonymous', $anonymous);

        $author_avatar = get_user_meta($details->user_id, 'avatar', true);
        $author_name   = get_userdata($details->user_id);
        $author_name   = $author_name->display_name;
        
        if (!$author_name) {
            $author_name = $details->comment_author;
            $details->comment_author_name = $author_name;
        }
        if (!$author_avatar) {
            $author_avatar = conikal_get_avatar_url( $author->ID, array('size' => 64) );
            $details->comment_author_avatar = $author_avatar;
        }
        
        $details->comment_author_name = $author_name;
        $details->comment_author_avatar = $author_avatar;
        if ($comment_id != 0) {
            return $comment_id;
        } else {
            return false;
        }

        die();
    }
endif;


/**
 * Get comment list
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_comments_petition') ): 
    function conikal_comments_petition($post_id, $parent_id = 0, $comments_sort = false, $replies_sort = false, $comments_per_page = false, $reply_per_comment = false) {
        global $campoal_options;
        global $current_user;
        
        if (empty($comments_sort)) {
            $comments_sort = isset($campoal_options['conikal_comments_sort_field']) ? $campoal_options['conikal_comments_sort_field'] : 'DESC';
        }

        if (empty($replies_sort)) {
            $replies_sort = isset($campoal_options['conikal_replies_sort_field']) ? $campoal_options['conikal_replies_sort_field'] : 'DESC';
        }

        if (empty($comments_per_page)) {
            $comments_per_page_setting = isset($campoal_options['conikal_comments_per_page_field']) ? $campoal_options['conikal_comments_per_page_field'] : '';
            $comments_per_page = $comments_per_page_setting != '' ? $comments_per_page_setting : 10;
        }
        
        if (empty($reply_per_comment)) {
            $reply_per_comment_setting = isset($campoal_options['conikal_reply_per_comment_field']) ? $campoal_options['conikal_reply_per_comment_field'] : '';
            $reply_per_comment = $reply_per_comment_setting != '' ? $reply_per_comment_setting : 3;
        }

        if ($parent_id == 0) {
            $number = $comments_per_page;
        } else {
            $number = $reply_per_comment;
            $comments_sort = $replies_sort;
        }

        // query comment
        $comments = get_comments(array(
            'status' => 'approve',
            'post_id' => $post_id,
            'number' => $number,
            'parent' => $parent_id,
            'orderby' => 'comment_date',
            'order' => 'DESC'
        ));

        // Avatar placeholder
        $lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

        $arrayComments = array();
        if ($comments) :
            foreach($comments as $comment) :
                    // get author name and avatar
                    $author_data    = get_userdata($comment->user_id);
                    if ($author_data) {
                        $author_name            = $author_data->display_name;
                        $author_avatar          = conikal_get_avatar_url( $author_data->ID, array('size' => 64) );
                        $author_avatar_retina   = conikal_get_avatar_url( $author_data->ID, array('size' => 128) );
                        $author_link            = get_author_posts_url($author_data->ID);
                    } else {
                        $author_name            = $comment->comment_author;
                        $author_avatar          = conikal_get_avatar_url( 0, array('size' => 64) );
                        $author_avatar_retina   = conikal_get_avatar_url( 0, array('size' => 128) );
                        $author_link            = $comment->comment_author_url;
                    }

                    // set author name and avatar for anonymous comment
                    $anonymous = get_comment_meta($comment->comment_ID, 'comment_anonymous', true);
                    if ($anonymous == 1 || $anonymous == 'true') {
                        $author_avatar          = conikal_get_avatar_url( 0, array('size' => 64) );
                        $author_avatar_retina   = conikal_get_avatar_url( 0, array('size' => 128) );
                        $author_name            = esc_html__('Anonymous', 'campoal-tapo');
                        $author_link            = '#';
                    }
                    
                    // calcular diff time
                    $comment_time = strtotime($comment->comment_date, current_time('timestamp'));
                    $comment_time = sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff($comment_time, current_time('timestamp')));
                    
                    // check comment are voted or not
                    $votes = get_comment_meta($comment->comment_ID, 'comment_vote', true);
                    if (is_array($votes) && in_array($current_user->ID, $votes)) {
                        $voted = true;
                    } else {
                        $voted = false;
                    }

                    if (class_exists('Give') && function_exists('conikal_contribution_level_badge')) {
                        $level_badge = conikal_contribution_level_badge($comment->user_id);
                    } else {
                        $level_badge = '';
                    }

                    $arrayComment = array(
                        'comment_ID'                    => $comment->comment_ID, 
                        'comment_post_ID'               => $comment->comment_post_ID, 
                        'comment_author'                => $comment->comment_author,
                        'comment_author_name'           => $author_name,
                        'comment_author_avatar'         => $author_avatar,
                        'comment_author_avatar_retina'  => $author_avatar_retina,
                        'comment_placeholder_avatar'    => $lazy_placeholder_avatar,
                        'comment_author_link'           => $author_link,
                        'comment_author_email'          => $comment->comment_author_email,
                        'comment_author_url'            => $comment->comment_author_url,
                        'comment_author_IP'             => $comment->comment_author_IP,
                        'comment_date'                  => $comment->comment_date,
                        'comment_date_gmt'              => $comment->comment_date_gmt,
                        'comment_time'                  => $comment_time,
                        'comment_content'               => get_comment_text($comment->comment_ID),
                        'comment_karma'                 => $comment->comment_karma,
                        'comment_approved'              => $comment->comment_approved,
                        'comment_agent'                 => $comment->comment_agent,
                        'comment_type'                  => $comment->comment_type,
                        'comment_parent'                => $comment->comment_parent,
                        'comment_vote'                  => ($votes ? count($votes) : 0),
                        'comment_voted'                 => $voted,
                        'comment_level_badge'           => $level_badge,
                        'user_id'                       => $comment->user_id
                    );
                    $arrayComment = (object) $arrayComment;
                    array_push($arrayComments, $arrayComment);
            endforeach;
        endif;

        if ($comments_sort == 'oldest') {
            $comments = array_reverse($arrayComments);
        } else {
            $comments = $arrayComments;
        }

        return $comments;

        die();
    }
endif;


/**
 * Load more comments
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_load_comments') ): 
    function conikal_load_comments() {
        global $campoal_options;
        global $post;
        global $current_user;

        $comments_sort = isset($campoal_options['conikal_comments_sort_field']) ? $campoal_options['conikal_comments_sort_field'] : 'oldest';
        $replies_sort = isset($campoal_options['conikal_replies_sort_field']) ? $campoal_options['conikal_replies_sort_field'] : 'newest';
        $comments_per_page_setting = isset($campoal_options['conikal_comments_per_page_field']) ? $campoal_options['conikal_comments_per_page_field'] : '';
        $comments_per_page = $comments_per_page_setting != '' ? $comments_per_page_setting : 10;
        $reply_per_comment_setting = isset($campoal_options['conikal_reply_per_comment_field']) ? $campoal_options['conikal_reply_per_comment_field'] : '';
        $reply_per_comment = $reply_per_comment_setting != '' ? $reply_per_comment_setting : 3;

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : $post->ID;
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : $current_user->ID;
        $parent_id = isset($_POST['parent_id']) ? sanitize_text_field($_POST['parent_id']) : 0;
        $offset = isset($_POST['offset']) ? sanitize_text_field($_POST['offset']) : 0;

        if ($parent_id != 0) {
            $comments_per_page = '';
            $comments_sort = $replies_sort;
        }

        $comments = get_comments(array(
            'status' => 'approve',
            'post_id' => $post_id,
            'number' => $comments_per_page,
            'parent' => $parent_id,
            'offset' => $offset,
            'orderby' => 'comment_date',
            'order' => 'DESC'
        ));

        // Avatar placeholder
        $lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');
        
        $arrayComments = array();
        if ($comments) :
            foreach($comments as $comment) :
                    $author_data   = get_userdata($comment->user_id);
                    // get author name and avatar
                    $author_data    = get_userdata($comment->user_id);
                    if ($author_data) {
                        $author_name            = $author_data->display_name;
                        $author_avatar          = conikal_get_avatar_url($author_data->ID, array('size' => 64));
                        $author_avatar_retina   = conikal_get_avatar_url($author_data->ID, array('size' => 128));
                        $author_link            = get_author_posts_url($author_data->ID);
                    } else {
                        $author_name            = $comment->comment_author;
                        $author_avatar          = conikal_get_avatar_url(0, array('size' => 64));
                        $author_avatar_retina   = conikal_get_avatar_url(0, array('size' => 128));
                        $author_link            = $comment->comment_author_url;
                    }

                    // set author name and avatar for anonymous comment
                    $anonymous = get_comment_meta($comment->comment_ID, 'comment_anonymous', true);
                    if ($anonymous == 1 || $anonymous == 'true') {
                        $author_avatar          = conikal_get_avatar_url(0, array('size' => 64));
                        $author_avatar_retina   = conikal_get_avatar_url(0, array('size' => 128));
                        $author_name            = esc_html__('Anonymous', 'campoal-tapo');
                        $author_link            = '#';
                    }

                    $comment_time = strtotime($comment->comment_date, current_time('timestamp'));
                    $comment_time = sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff($comment_time, current_time('timestamp')));
                    $votes = get_comment_meta($comment->comment_ID, 'comment_vote', true);
                    $vote_number = is_array($votes) ? count($votes) : 0;
                    if (is_array($votes) && in_array($current_user->ID, $votes)) {
                        $voted = true;
                    } else {
                        $voted = false;
                    }

                    if (class_exists('Give') && function_exists('conikal_contribution_level_badge')) {
                        $level_badge = conikal_contribution_level_badge($comment->user_id);
                    } else {
                        $level_badge = '';
                    }

                    $arrayComment = array(
                        'comment_ID'                    => $comment->comment_ID, 
                        'comment_post_ID'               => $comment->comment_post_ID, 
                        'comment_author'                => $comment->comment_author,
                        'comment_author_name'           => $author_name,
                        'comment_author_avatar'         => $author_avatar,
                        'comment_author_avatar_retina'  => $author_avatar_retina,
                        'comment_placeholder_avatar'    => $lazy_placeholder_avatar,
                        'comment_author_link'           => $author_link,
                        'comment_author_email'          => $comment->comment_author_email,
                        'comment_author_url'            => $comment->comment_author_url,
                        'comment_author_IP'             => $comment->comment_author_IP,
                        'comment_date'                  => $comment->comment_date,
                        'comment_date_gmt'              => $comment->comment_date_gmt,
                        'comment_time'                  => $comment_time,
                        'comment_content'               => get_comment_text($comment->comment_ID),
                        'comment_karma'                 => $comment->comment_karma,
                        'comment_approved'              => $comment->comment_approved,
                        'comment_agent'                 => $comment->comment_agent,
                        'comment_type'                  => $comment->comment_type,
                        'comment_parent'                => $comment->comment_parent,
                        'comment_vote'                  => $vote_number,
                        'comment_vote_label'            => _n('like', 'likes', $vote_number, 'campoal-tapo'),
                        'comment_voted'                 => $voted,
                        'comment_level_badge'           => $level_badge,
                        'user_id'                       => $comment->user_id
                    );
                    $replies = conikal_comments_petition($post_id, $comment->comment_ID);
                    $arrayComment = (object) $arrayComment;
                    if ($replies) {
                        $arrayComment->replies = $replies;
                    }
                    $replies_total = get_comments(array(
                        'status' => 'approve',
                        'post_id' => $post_id,
                        'parent' => $comment->comment_ID,
                        'order' => 'DESC'
                    ));
                    $arrayComment->replies_total = count($replies_total);
                    array_push($arrayComments, $arrayComment);
            endforeach;
        endif;

        if ($comments_sort == 'oldest') {
            $comments = array_reverse($arrayComments);
        } else {
            $comments = $arrayComments;
        }

        if ($comments) {
            echo json_encode(array('status' => true, 'per_page' => $comments_per_page, 'per_comment' => $reply_per_comment, 'comments' => $comments, 'message' => esc_html__('Comments was loaded successfully', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. Not found comments.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_load_comments', 'conikal_load_comments' );
add_action( 'wp_ajax_conikal_load_comments', 'conikal_load_comments' );

/**
 * Sets the cookies used to store an unauthenticated commentator's identity. Typically used
 * to recall previous comments by this commentator that are still held in moderation.
 *
 * @since Campoal Tapo 2.0.6
 */
if( !function_exists('conikal_set_comment_cookies') ): 
    function conikal_set_comment_cookies( $comment, $cookies_consent = true ) {

        if ( false === $cookies_consent ) {
            // Remove any existing cookies.
            $past = time() - YEAR_IN_SECONDS;
            setcookie( 'comment_author_' . COOKIEHASH, ' ', $past, COOKIEPATH, COOKIE_DOMAIN );
            setcookie( 'comment_author_email_' . COOKIEHASH, ' ', $past, COOKIEPATH, COOKIE_DOMAIN );
            setcookie( 'comment_author_url_' . COOKIEHASH, ' ', $past, COOKIEPATH, COOKIE_DOMAIN );

            return;
        }

        /**
         * Filters the lifetime of the comment cookie in seconds.
         *
         * @since 2.8.0
         *
         * @param int $seconds Comment cookie lifetime. Default 30000000.
         */
        $comment_cookie_lifetime = time() + apply_filters( 'comment_cookie_lifetime', 30000000 );

        $secure = ( 'https' === parse_url( home_url(), PHP_URL_SCHEME ) );

        setcookie( 'comment_author_' . COOKIEHASH, $comment->comment_author, $comment_cookie_lifetime, COOKIEPATH, COOKIE_DOMAIN, $secure );
        setcookie( 'comment_author_email_' . COOKIEHASH, $comment->comment_author_email, $comment_cookie_lifetime, COOKIEPATH, COOKIE_DOMAIN, $secure );
        setcookie( 'comment_author_url_' . COOKIEHASH, esc_url( $comment->comment_author_url ), $comment_cookie_lifetime, COOKIEPATH, COOKIE_DOMAIN, $secure );
    }
endif;

?>