<?php 

/**
 * Include the custom JS in the header tag
 *
 * @since Campoal Tapo 1.0.0
 */
if ( ! function_exists( 'conikal_load_wp_head' ) ) {
    function conikal_load_wp_head() {
        global $campoal_options;
        $custom_js   = isset($campoal_options['conikal_header_custom_js_field']) ? $campoal_options['conikal_header_custom_js_field'] : '';
        $js_ready    = isset($campoal_options['conikal_header_js_ready_field']) ? $campoal_options['conikal_header_js_ready_field'] : '';
        ?>
        
        <?php if( !empty( $custom_js ) || !empty( $js_ready ) ): ?>
            <script type="text/javascript">
                <?php if( !empty( $custom_js ) ): ?>
                    <?php echo esc_js($custom_js); ?>
                <?php endif; ?>
                <?php if( !empty( $js_ready ) ): ?>
                    jQuery(document).ready(function() {
                        <?php echo esc_js($js_ready); ?>
                    });
                <?php endif; ?>
            </script>
        <?php endif; ?>

        <?php
    }

    add_action( 'wp_head', 'conikal_load_wp_head' );
}

/**
 * Include the custom JS before close body tag.
 *
 * @since Campoal Tapo 1.0.0
 */
if ( ! function_exists( 'conikal_load_wp_footer' ) ) {
    function conikal_load_wp_footer() {
        global $campoal_options;
        $custom_js          = isset($campoal_options['conikal_custom_js_field']) ? $campoal_options['conikal_custom_js_field'] : '';
        $js_ready           = isset($campoal_options['conikal_js_ready_field']) ? $campoal_options['conikal_js_ready_field'] : '';
        ?>
        
        <?php if( !empty( $custom_js ) || !empty( $js_ready ) ): ?>
            <script type="text/javascript">
                <?php if( !empty( $custom_js ) ): ?>
                    <?php echo esc_js($custom_js); ?>
                <?php endif; ?>
                <?php if( !empty( $js_ready ) ): ?>
                    jQuery(document).ready(function() {
                        <?php echo esc_js($js_ready); ?>
                    });
                <?php endif; ?>
            </script>
        <?php endif; ?>

        <?php
    }

    add_action( 'wp_footer', 'conikal_load_wp_footer' );
}


/**
 * Embed Facebook SDK for Login and Share button
 *
 * @since Campoal Tapo 1.0.0
 */
add_action( 'wp_footer', 'conikal_facebook_sdk_script' );
if (!function_exists('conikal_facebook_sdk_script')) :
    function conikal_facebook_sdk_script() {
        global $campoal_options;

        // Facebook Graph API
        $fb_login = isset($campoal_options['conikal_fb_login_field']) ? $campoal_options['conikal_fb_login_field'] : 0;
        $fb_app_version = isset($campoal_options['conikal_fb_version_field']) ? $campoal_options['conikal_fb_version_field'] : 'v3.1';
        $fb_app_id = isset($campoal_options['conikal_fb_id_field']) ? $campoal_options['conikal_fb_id_field'] : '';
        $citation = isset($campoal_options['conikal_citation_field']) ? $campoal_options['conikal_citation_field'] : 1;
        
        $ajax_pages = isset($campoal_options['conikal_ajax_pages_field']) ? $campoal_options['conikal_ajax_pages_field'] : 0;

        $facebook_init = '
            window.fbAsyncInit = function() {
                FB.init({
                  appId      : ' . esc_attr($fb_app_id) . ',
                  cookie     : true,
                  xfbml      : true,
                  version    : "' . esc_attr($fb_app_version) . '",
                  status     : true,
                });
                FB.AppEvents.logPageView();   
              };

              (function(d, s, id){
                 var js, fjs = d.getElementsByTagName(s)[0];
                 if (d.getElementById(id)) {return;}
                 js = d.createElement(s); js.id = id;
                 js.src = "//connect.facebook.net/en_US/sdk.js";
                 fjs.parentNode.insertBefore(js, fjs);
               }(document, "script", "facebook-jssdk"));
        ';

        if ($fb_login == 1 && $fb_app_id != '' && $ajax_pages == 1) {
            wp_add_inline_script('campoal-services', $facebook_init, 'before');
        } else {
            if($fb_login == 1 && $fb_app_id != '' && !is_user_logged_in()) {
                wp_add_inline_script('campoal-services', $facebook_init, 'before');

                if ($citation && is_page()) {
                    get_template_part('templates/citation-modal');
                }
            } elseif ((is_singular('post') || is_singular('petition') || is_singular('update') || is_singular('citation') || is_singular('give_forms') || is_page_template('sign-successful.php')) && is_user_logged_in() && $fb_app_id != '' && $fb_login == 1) {
                wp_add_inline_script('campoal-services', $facebook_init, 'before');
            } elseif (is_user_logged_in() && is_page_template('user-account.php') && $fb_login == 1 && $fb_app_id != '') {
                wp_add_inline_script('campoal-services', $facebook_init, 'before');
            } elseif (is_page() && $fb_app_id != '' && $fb_login == 1) {
                wp_add_inline_script('campoal-services', $facebook_init, 'before');

                // get modal submit citation
                if ($citation) {
                    get_template_part('templates/citation-modal');
                }
            };
        }
    }
endif;
?>