<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Get decision makers
 *
 * @since Campoal Tapo 1.6.5
 */
if (!function_exists('conikal_get_decistion_makers')) :
    function conikal_get_decistion_makers($petition_id, $show_string = false, $display = 0) {
        if (empty($petition_id)) {
            return;
        }

        global $campoal_options;
        $decisionmakers_display = isset($campoal_options['conikal_decisionmakers_display_field']) ? $campoal_options['conikal_decisionmakers_display_field'] : 1;

        $decisionmakers = rwmb_meta('petition_decisionmakers', null, $petition_id);
        $decisionmakers = is_array($decisionmakers) ? $decisionmakers : array_filter( array_unique(explode(',', $decisionmakers)) );
        $receiver = get_post_meta($petition_id, 'petition_receiver', true);
        $receiver = explode(',', $receiver);
        $position = get_post_meta($petition_id, 'petition_position', true);
        $position = explode(',', $position);

        $display_number = (count($receiver) - 1);
        $all_decisionmakers = array();
        if ($display == 0) {
            if( !empty($decisionmakers) ) {     
                foreach ($decisionmakers as $id) {
                    if (get_post_type($id) == 'decisionmakers') {
                        $id = get_post_field ('post_author', $id);
                    }
                    $user = get_userdata($id);
                    if (!empty($user)) {
                        $user_id                = $user->ID;
                        $user_name              = $user->display_name;
                        $user_email             = $user->user_email;
                        $user_avatar            = conikal_get_avatar_url( $user_id, array('size' => 64) );
                        $user_avatar_retina     = conikal_get_avatar_url( $user_id, array('size' => 128) );
                        $user_url               = get_author_posts_url( $user_id );

                        $user_decisionmakers    = get_user_meta($user_id, 'user_decision', true);

                        if ($user_decisionmakers) {
                            $decision_title     =  wp_get_post_terms($user_decisionmakers, 'decisionmakers_title', true);
                            $decision_title     = ($decision_title ? $decision_title[0]->name : '');
                            $organization       =  wp_get_post_terms($user_decisionmakers, 'decisionmakers_organization', true);
                            $organization       = ($organization ? $organization[0]->name : '');

                            array_push($all_decisionmakers, array(
                                'id'            => $id,
                                'user_id'       => $user_id,
                                'name'          => $user_name,
                                'position'      => sprintf(esc_html__('%1$s of %2$s', 'campoal-tapo'), $decision_title, $organization),
                                'email'         => $user_email,
                                'avatar'        => $user_avatar,
                                'avatar_retina' => $user_avatar_retina,
                                'url'           => $user_url,
                            ));
                        }
                    }
                } 
            }
        } else {
            $display_number = ($display_number >= $display ? $display : $display_number);
        }

        $default_avatar         = conikal_get_avatar_url( 0, array('size' => 64) );
        $default_avatar_retina  = conikal_get_avatar_url( 0, array('size' => 128) );
        
        // re-contruct decision maker with out user
        $decisionmakers_without_account = array();
        for ($i=0; $i < $display_number; $i++) {
            if (array_key_exists($i, $receiver)) {
                $decisionmakers_without_account[] = array(
                    'id'            => '',
                    'user_id'       => '',
                    'name'          => $receiver[$i],
                    'position'      => $position[$i],
                    'email'         => '',
                    'avatar'        => $default_avatar,
                    'avatar_retina' => $default_avatar_retina,
                    'url'           => '',
                );
            }
        }

        $results = array_merge($all_decisionmakers, $decisionmakers_without_account);

        // remove duplicate decision makers
        $results = conikal_unique_multidim_array($results, 'name');

        // display result as complate string
        if ($show_string) {
            if (!empty($results)) {
                $string = '';
                $total_show = count($results);
                $i = 1;
                foreach ($results as $index => $receiver) {
                    $string .= $receiver['name'] . ($i < $total_show ? ', ' : '');
                    $results = $string;

                    $i++;
                }
            } else {
                $results = '';
            }
        }

        return $results;
    }
endif;


/**
 * Send email to decision maker when petition reach new milestone supporters
 *
 * @since Campoal Tapo 2.0.0
 */
if( !function_exists('conikal_decision_maker_new_milestone_notification') ): 
    function conikal_decision_maker_new_milestone_notification($post_id, $author_id = 0) {
        global $campoal_options;
        
        $decision_maker_percent_reached = isset($campoal_options['conikal_decision_maker_percent_reached_field']) ? $campoal_options['conikal_decision_maker_percent_reached_field'] : 0;
        $decision_maker_new_milestone = isset($campoal_options['conikal_decision_maker_new_milestone_field']) ? $campoal_options['conikal_decision_maker_new_milestone_field'] : 0;

        // get enabled milestone percents
        $percents = array_filter($decision_maker_percent_reached, function($percent) {
            return $percent == 1;
        });

        // get author id
        if ($author_id == 0) {
            $author_id = get_post_field( 'post_author', $post_id );
        }

        if (!empty($percents) && $decision_maker_new_milestone == 1) {
            $sign_no = get_post_meta($post_id, 'petition_sign', true);
            $goal_no = get_post_meta($post_id, 'petition_goal', true);

            foreach ($percents as $percent => $status) {
                $milestone = (int)$goal_no * ((int)$percent / 100);

                // send email to decision maker when signature reach milestone
                if ($sign_no == $milestone) {
                    $sent = conikal_decision_maker_notification('milestone', $post_id, $author_id);
                } else {
                    $sent = false;
                }
            }
        } else {
            $sent = false;
        }

        return $sent;
    }
endif;