<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */



/**
 * Function that sends email message from contact page form
 */
if( !function_exists('conikal_send_message_to_company') ): 
    function conikal_send_message_to_company() {
        check_ajax_referer('contact_page_ajax_nonce', 'security');

        global $campoal_options;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $company_email = isset($_POST['company_email']) ? sanitize_email($_POST['company_email']) : '';
        $client_name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $client_email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $client_subject = isset($_POST['subject']) ? sanitize_text_field($_POST['subject']) : '';
        $client_message = isset($_POST['message']) ? sanitize_text_field($_POST['message']) : '';

        if(empty($client_name) || empty($client_email) || empty($client_subject) || empty($client_message)) {
            echo json_encode(array('status'=>false, 'message'=> esc_html__('Your message failed to be sent. Please check your fields.', 'campoal-tapo')));
            exit();
        }

        $headers = 'From: ' . $client_name . '  <' . $client_email . '>' . "\r\n" .
                'Reply-To: ' . $client_name . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        $client_info = sprintf( esc_html__('Sent from: %s', 'campoal-tapo'), $client_name ) . "\r\n";
        $client_info .= sprintf( esc_html__('Email: %s', 'campoal-tapo'), $client_email ) . "\r\n";
        $client_message .=  "\r\n\r\n" . $client_info;

        // apply general template
        $client_message = conikal_apply_general_template($client_subject, $client_message);

        $send = wp_mail(
            $company_email,
            sprintf( esc_html__('[%s Contact] %s', 'campoal-tapo'), $client_name, $client_subject ),
            $client_message,
            ($email_header ? $headers : '')
        );

        if($send) {
            echo json_encode(array('status'=>true, 'message'=> esc_html__('Your message was successfully sent.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=> esc_html__('Your message failed to be sent.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_send_message_to_company', 'conikal_send_message_to_company' );
add_action( 'wp_ajax_conikal_send_message_to_company', 'conikal_send_message_to_company' );


/**
 * Sends email message from contact user form
 */
if( !function_exists('conikal_send_message_to_user') ): 
    function conikal_send_message_to_user() {
        check_ajax_referer('contact_user_ajax_nonce', 'security');

        global $campoal_options;
        $recaptcha_contact = isset($campoal_options['conikal_google_recaptcha_contact_field']) ? $campoal_options['conikal_google_recaptcha_contact_field'] : 1;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $allowed_html = array();
        $user_email = isset($_POST['user_email']) ? sanitize_email($_POST['user_email']) : '';
        $client_name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $client_email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $client_subject = isset($_POST['subject']) ? sanitize_text_field($_POST['subject']) : '';
        $client_message = isset($_POST['message']) ? wp_kses($_POST['message'], $allowed_html) : '';

        if(empty($client_name) || empty($client_email) || empty($client_subject) || empty($client_message)) {
            echo json_encode(array('status'=>false, 'message'=> esc_html__('Your message failed to be sent. Please check your fields.', 'campoal-tapo')));
            exit();
        }

        // Vertify Google reCAPTCHA
        if (conikal_show_google_reCaptcha() && $recaptcha_contact == 1) {
            conikal_google_recaptcha_callback();
        }

        // apply general template
        $client_message = conikal_apply_general_template($client_subject, $client_message);

        $headers = 'From: ' . $client_name . '  <' . $client_email . '>' . "\r\n" .
                'Reply-To: ' . $client_name . "\r\n" .  
                'X-Mailer: PHP/' . phpversion();
                
        $send = wp_mail(
            $user_email,
            sprintf( esc_html__('[%s Message] %s', 'campoal-tapo'), get_option('blogname'), $client_subject ),
            $client_message,
            ($email_header ? $headers : '')
        );

        if($send) {
            echo json_encode(array('status'=>true, 'message'=> esc_html__('Your message was successfully sent.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=> esc_html__('Your message failed to be sent.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_send_message_to_user', 'conikal_send_message_to_user' );
add_action( 'wp_ajax_conikal_send_message_to_user', 'conikal_send_message_to_user' );


/**
 * Sends invitation letter to decision makers
 */

if( !function_exists('conikal_send_invatation') ): 
    function conikal_send_invatation() {
        check_ajax_referer('invitation_ajax_nonce', 'security');
        global $campoal_options;
        $invite_decision_makers_template = isset($campoal_options['conikal_invite_decision_email_template_field']) ? $campoal_options['conikal_invite_decision_email_template_field'] : 'noreply';
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $allowed_html = array();
        $user_email = isset($_POST['user_email']) ? sanitize_email($_POST['user_email']) : '';
        $invite_name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $invite_decision_name = isset($_POST['decision_name']) ? sanitize_text_field($_POST['decision_name']) : '';
        $invite_email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $invite_title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
        $invite_subject = isset($_POST['subject']) ? sanitize_text_field($_POST['subject']) : '';
        $invite_message = isset($_POST['message']) ? wp_kses($_POST['message'], $allowed_html) : '';
        $invite_link = isset($_POST['link']) ? sanitize_text_field($_POST['link']) : '';

        if(empty($invite_name) || empty($invite_email) || empty($invite_subject) || empty($invite_message)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Your message failed to be sent. Please check your fields.', 'campoal-tapo')));
            exit();
        }

        // custom comment variables
        $vars_find     = array(
            '%invite_name%',
            '%invite_decision_name%',
            '%invite_title%',
            '%invite_subject%',
            '%invite_message%',
            '%invite_link%'
        );
        $vars_replace  = array(
            esc_html($invite_name),
            esc_html($invite_decision_name),
            esc_html($invite_title),
            esc_html($invite_subject),
            $invite_message,
            esc_url($invite_link),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        // replace variables in template with values
        $message = str_replace($vars_find, $vars_replace, $invite_decision_makers_template);
        $message = conikal_apply_general_template($invite_subject, $message);

        $headers = 'From: ' . $invite_name . '  <' . $user_email . '>' . "\r\n" .
                'Reply-To: ' . $invite_name . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        $send = wp_mail(
            $invite_email,
            sprintf( esc_html__('[%s] %s', 'campoal-tapo'), get_option('blogname'), $invite_subject ),
            $message,
            ($email_header ? $headers : '')
        );

        if($send) {
            echo json_encode(array('status'=>true, 'message'=> esc_html__('Your message was successfully sent.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=> esc_html__('Your message failed to be sent.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_send_invatation', 'conikal_send_invatation' );
add_action( 'wp_ajax_conikal_send_invatation', 'conikal_send_invatation' );


?>