<?php 

/*
 * Google reCaptcha filter
 * */
if(!function_exists('conikal_google_recaptcha_callback')) {
    function conikal_google_recaptcha_callback() {
        global $campoal_options;

        $recaptcha_site_key      = isset($campoal_options['conikal_google_recaptcha_key_field']) ? $campoal_options['conikal_google_recaptcha_key_field'] : '';
        $recaptcha_secret_key    = isset($campoal_options['conikal_google_recaptcha_secret_field']) ? $campoal_options['conikal_google_recaptcha_secret_field'] : '';
        $enable_reCaptcha        = isset($campoal_options['conikal_google_recaptcha_field']) ? $campoal_options['conikal_google_recaptcha_field'] : 0;
        $recaptcha_position      = isset($campoal_options['conikal_google_recaptcha_position_field']) ? $campoal_options['conikal_google_recaptcha_position_field'] : 'inline';

        if( $enable_reCaptcha != 1 ) {
            return true;
        }

        // include library https://github.com/google/recaptcha
        include_once(  plugin_dir_path( __DIR__ ) . 'libs/recaptcha/src/autoload.php' );

        // If the form submission includes the "g-captcha-response" field
        // Create an instance of the service using your secret

        $recaptcha = new \ReCaptcha\ReCaptcha( $recaptcha_secret_key, new \ReCaptcha\RequestMethod\CurlPost() );

        // If file_get_contents() is locked down on your PHP installation to disallow
        // its use with URLs, then you can use the alternative request method instead.
        // This makes use of fsockopen() instead.

        if (empty($_POST["g-recaptcha-response"])) {
            echo json_encode( array(
                'status' => false,
                'message' => esc_html__( 'reCAPTCHA Failed: The response parameter is missing.', 'campoal-tapo')
            ) );
            wp_die();
        }

        // Make the call to verify the response and also pass the user's IP address
        $resp = $recaptcha->verify($_POST["g-recaptcha-response"], $_SERVER['REMOTE_ADDR']);


        if ($resp->isSuccess()):
            return true;
        else:

            $error_codes   = $resp->getErrorCodes();

            //Error codes - https://developers.google.com/recaptcha/docs/verify
            $captach_errors  = array(
                'missing-input-secret'   => esc_html__('The secret parameter is missing.', 'campoal-tapo'),
                'invalid-input-secret'   => esc_html__('The secret parameter is invalid or malformed.', 'campoal-tapo'),
                'missing-input-response' => esc_html__('The response parameter is missing.', 'campoal-tapo'),
                'invalid-input-response' => esc_html__('The response parameter is invalid or malformed.', 'campoal-tapo'),
                'bad-request' => esc_html__('The request is invalid or malformed.', 'campoal-tapo'),
            );
            $error_message = $captach_errors[ $error_codes[ 0 ]];
            echo json_encode( array(
                'status' => false,
                'message' => esc_html__( 'reCAPTCHA Failed:', 'campoal-tapo') . ' ' . $error_message
            ) );
            wp_die();
        endif;
    }
}
?>