<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
**/

function ConikalLicense() {
    $conikal_campoal_license = new LMFW\SDK\License( 
        'campoal-tapo',   // The plugin name is used to manage internationalization
        'https://www.conikal.com', //Replace with the URL of your license server (without the trailing slash)
        'ck_6bec0581e77b68ae4d8cdfdf4c7790dcf600b4ad', //Customer key created in the license server
        'cs_54a68426cd895641825736c46c15414f60143887', //Customer secret created in the license server
        [560,15354,15355,15356,20156,43629,43630], //Set an array of the products IDs on your license server (if no product validation is needed, send an empty array)
        'campoal_license', //Set a unique value to avoid conflict with other plugins
        'campoal-is-valid',  //Set a unique value to avoid conflict with other plugins
        6 //How many days the valid object will be used before calling the license server
    );

    return $conikal_campoal_license;
}

register_activation_hook( __FILE__, 'conikal_license_check_schedule' );
register_deactivation_hook( __FILE__, 'conikal_license_check_schedule_stop' );

# Schedule license validity check event (use a unique schedule name)
conikal_license_check_schedule();
function conikal_license_check_schedule() {
    if( !wp_next_scheduled( 'conikal_campoal_license_validity' ) ) {
        wp_schedule_event( time(), 'weekly', 'conikal_campoal_license_validity' );
    }
}

# Add validity function hook
add_action('conikal_campoal_license_validity', 'conikal_campoal_license_validation');

# Create the validity function called by the hook
function conikal_campoal_license_validation() {
    $license = ConikalLicense();
    
    $valid_status = $license->validate_status();
    $vaidate_object = get_option('campoal-is-valid');
    if (empty($valid_status['is_valid']) || $valid_status['is_valid'] != 1) {
        delete_site_transient('conikal-license-notice-dismissed');

        if (!isset($vaidate_object['failed_times'])) {
            $vaidate_object['failed_times'] = 0;
        } else {
            $vaidate_object['failed_times'] = $vaidate_object['failed_times'] + 1;
            if (intval($vaidate_object['failed_times']) > 3) {
                $vaidate_object['revoked'] = 0;
                $vaidate_object['email_sent'] = 0;
            }
        }
    } else {
        $vaidate_object['failed_times'] = 0;
        $vaidate_object['revoked'] = 1;
        $vaidate_object['email_sent'] = 1;
    }
    update_option('campoal-is-valid', $vaidate_object);

    return $valid_status;
}

// Delete theme if reach 3 times failed validations
function conikal_revoked_campoal_theme($vaidate_object) {
    if (!empty($vaidate_object)) {
        if (isset($vaidate_object['failed_times'])) {
            if (intval($vaidate_object['failed_times']) > 3) {
                return delete_theme('campoal');
            }
        }
    }
}

function conikal_license_check_schedule_stop() {
    wp_clear_scheduled_hook( 'conikal_campoal_license_validity' );
}

// Add license active notice message
if( !function_exists( 'the_field' ) && empty(get_site_transient( 'conikal-license-notice-dismissed' )) ) {
  add_action( 'admin_notices', 'conikal_license_active_notice' );
}

function conikal_license_active_notice() { 
    // $vaidate_object = get_option('campoal-is-valid');
    // print_r(get_option('campoal-is-valid'));
    // print_r(date_i18n('d-m-Y, H:m', wp_next_scheduled('conikal_campoal_license_validity')));
    // print_r('|' . date_i18n('d-m-Y, H:m', $vaidate_object['nextValidation']));
    // print_r('|' . date_i18n('d-m-Y, H:m', time()));
    // print_r(wp_clear_scheduled_hook('conikal_campoal_license_validity'));
    // print_r(conikal_campoal_license_validation());

    $license    = ConikalLicense();
    $vaidate_object = get_option('campoal-is-valid');
    $valid_status   = $license->validate_status();
    if (!array_key_exists('is_valid', $valid_status) || $valid_status['is_valid'] != 1 || empty($valid_status['github_token'])) {
        if (isset($vaidate_object['failed_times']) && intval($vaidate_object['failed_times']) > 6 && isset($vaidate_object['revoked']) && $vaidate_object['revoked'] == 0) {
            $revoked_theme = conikal_revoked_campoal_theme($vaidate_object);
            if ($revoked_theme) {
                $vaidate_object['failed_times'] = 0;
                $vaidate_object['revoked'] = 1;
                $vaidate_object['email_sent'] = 0;
                update_option('campoal-is-valid', $vaidate_object);

                // send revoked email notification
                conikal_remind_license_notification($vaidate_object);
            }
        }

        // send remind license email
        if (isset($vaidate_object['failed_times']) && intval($vaidate_object['failed_times']) > 3) {
            if (isset($vaidate_object['email_sent']) && $vaidate_object['email_sent'] == 0) {
                $send_remind = conikal_remind_license_notification($vaidate_object);
                if ($send_remind) {
                    $vaidate_object['email_sent'] = 1;
                }
                update_option('campoal-is-valid', $vaidate_object);
            }
        }
     ?>
        <div class="error notice">
            <p>
                <strong>
                    <?php esc_html_e('Campoal unlicensed: ', 'campoal-tapo') ?>    
                </strong>
                    <?php echo esc_html(!empty($valid_status['error']) ? $valid_status['error'] . '.' : '' ) ?>
                    <?php if (isset($vaidate_object['failed_times']) && intval($vaidate_object['failed_times']) > 0 && intval($vaidate_object['failed_times']) < 4) {
                        echo esc_html(sprintf('You have %s times license validation failed, after 3 failed attempts the Campoal theme will be revoked.', $vaidate_object['failed_times']));
                    } elseif (isset($vaidate_object['failed_times']) && intval($vaidate_object['failed_times']) <= 6 && (isset($vaidate_object['revoked']) && $vaidate_object['revoked'] == 1)) {
                        esc_html_e('You have passed 3 failed license validation attempts. Please enter the license validation to avoid your site being broken.', 'campoal-tapo');
                    } elseif (isset($vaidate_object['failed_times']) && intval($vaidate_object['failed_times']) > 6 || (isset($vaidate_object['revoked']) && $vaidate_object['revoked'] == 1) ) {
                        esc_html_e('The theme has been revoked due to lack of license, please visit Conikal.com to purchase a license. Thanks!', 'campoal-tapo');
                    } else {
                        esc_html_e('Please enter a licenses for Campoal to unlock features and receive automatic updates. ', 'campoal-tapo');
                    } ?>
                    <a href="<?php echo admin_url('options-general.php?page=conikal-license') ?>"><?php esc_html_e('Enter a license', 'campoal-tapo') ?></a>
        </p>
        </div>
    <?php } else { ?>
        <div class="updated notice conikal-license-notice is-dismissible" data-dismissible="conikal-license-notice-dismissed-0">
            <p>
                <strong><?php esc_html_e('Campoal licensed: ', 'campoal-tapo') ?></strong> 
                <?php echo sprintf(__('Your license has been activated successfully! All features have been unlocked, the theme and plugin will be updated automatically. Do you appreciate it? %s', 'campoal-tapo'), '<a href="//themeforest.net/item/campoal-social-movement-wordpress-theme/reviews/36150364" target="_blank">' . __('Write a review', 'campoal-tapo') . '</a>') ?>
            </p>
        </div>
    <?php }
}

/**
 * Handles Ajax request to persist notices dismissal.
 * Uses check_ajax_referer to verify nonce.
 */
function conikal_dismiss_admin_notice() {
    $option_name        = sanitize_text_field( $_POST['option_name'] );
    $dismissible_length = sanitize_text_field( $_POST['dismissible_length'] );
    $transient          = 0;

    if ( 'forever' != $dismissible_length ) {
        // If $dismissible_length is not an integer default to 1
        $dismissible_length = ( 0 == absint( $dismissible_length ) ) ? 1 : $dismissible_length;
        $transient          = absint( $dismissible_length ) * DAY_IN_SECONDS;
        $dismissible_length = strtotime( absint( $dismissible_length ) . ' days' );
    }

    // check_ajax_referer( 'dismissible-notice', 'nonce' );
    set_site_transient( $option_name, $dismissible_length, $transient );
    wp_die();
}

add_action( 'wp_ajax_conikal_dismiss_admin_notice', 'conikal_dismiss_admin_notice' );


/**
 * custom option and settings
 */
function conikal_license_settings_init() {
 // register a new setting for "campoal-tapo" page
 register_setting( 'conikal-license', 'conikal_license_validate_status_option' );
 register_setting( 'conikal-license', 'conikal_license_key_string_option' );

 
 // register a new section in the "campoal-tapo" page
 add_settings_section(
 'conikal_license_activate',
 __( 'Conikal License Activation', 'campoal-tapo' ),
 'conikal_campoal_license_section_developers_cb',
 'conikal-license'
 );
 
 // register a new field in the "conikal_pdo_section_developers" section, inside the "conikal-license" page
 add_settings_field(
     'conikal_license_validate_status', // as of WP 4.6 this value is used only internally
     // use $args' label_for to populate the id inside the callback
     __( 'Validate status', 'campoal-tapo' ),
     'conikal_license_validate_status_cb',
     'conikal-license',
     'conikal_license_activate',
     [
        'label_for' => 'conikal_license_validate_status',
        'class' => 'conikal_license_activate_row',
        'conikal_license_activate_custom_data' => 'custom',
     ]
 );

 add_settings_field(
     'conikal_license_key_string', // as of WP 4.6 this value is used only internally
     // use $args' label_for to populate the id inside the callback
     __( 'License key', 'campoal-tapo' ),
     'conikal_license_key_string_cb',
     'conikal-license',
     'conikal_license_activate',
     [
        'label_for' => 'conikal_license_key_string',
        'class' => 'conikal_license_activate_row',
        'conikal_license_activate_custom_data' => 'custom',
     ]
 );
}
 
/**
 * register our conikal_license_settings_init to the admin_init action hook
 */
add_action( 'admin_init', 'conikal_license_settings_init' );
 
/**
 * custom option and settings:
 * callback functions
 */
 
// developers section cb
 
// section callbacks can accept an $args parameter, which is an array.
// $args have the following keys defined: title, id, callback.
// the values are defined at the add_settings_section() function.
function conikal_campoal_license_section_developers_cb( $args ) {
 ?>
    <p id="<?php echo esc_attr( $args['id'] ); ?>">
        <?php _e('Use an Envato Purchase Code or a Conikal License key to activate Campoal to receive automatic updates and unlock the settings panel.', 'campoal-tapo') ?>
        <a href="<?php echo esc_url('http://docs.woocommerce.com/document/woocommerce-rest-api/') ?>"><?php //esc_html_e('instructions', 'campoal-tapo') ?></a>
    </p>
 <?php
}
 
// pill field cb
 
// field callbacks can accept an $args parameter, which is an array.
// $args is defined at the add_settings_field() function.
// wordpress has magic interaction with the following keys: label_for, class.
// the "label_for" key value is used for the "for" attribute of the <label>.
// the "class" key value is used for the "class" attribute of the <tr> containing the field.
// you can add custom key value pairs to be used inside your callbacks.
function conikal_license_validate_status_cb( $args ) {
    // get the value of the setting we've registered with register_setting()
    $options = get_option( 'conikal_license_validate_status_option' );
    $license_key_string = get_option( 'conikal_license_key_string_option', '' );
    // output the field
    $license = ConikalLicense();
    
    $license_status = $license->validate_status();

    if ( isset( $_GET['update-license']) || isset( $_GET['settings-updated'] ) ) {
        $license_status = $license->validate_status($license_key_string);
        
        //print_r( $license_status );

        if (empty($license_status['is_valid']) || $license_status['is_valid'] != 1) {
            delete_site_transient('conikal-license-notice-dismissed');
        } else {
            $vaidate_object = get_option('campoal-is-valid');
            $vaidate_object['failed_times'] = 0;
            update_option('campoal-is-valid', $vaidate_object);
        }
    }
 ?>
    <p class="">
        <div class="ui <?php echo esc_attr(!empty($license_status['is_valid']) ? 'green' : 'red' ) ?> label"><?php echo esc_html(!empty($license_status['is_valid']) ? __('Activated', 'campoal-tapo') : __('Not activated', 'campoal-tapo') ) ?></div>
        <span><?php echo esc_html($license_status['error']) ?></span>
        <a href="<?php echo add_query_arg(array('page' => 'conikal-license', 'update-license' => true), admin_url('options-general.php')) ?>"><?php esc_html_e('Re-validate', 'campoal-tapo') ?></a>
    </p>
    <p>
        <?php 
            if ( isset( $_GET['update-license']) || isset( $_GET['settings-updated'] ) ) { ?>
                <?php if (array_key_exists('data', $license_status)) {
                    // print_r($license_status); ?>
                <?php } else { ?>
                <p>
                    <?php echo sprintf(__( 'To deactivate license, please go to <strong>My Account > License keys</strong> at %s and click on Deactivate button.', 'campoal-tapo' ), '<a target="_blank" href="//www.conikal.com/my-account/view-license-keys/">Conikal.com</a>'); ?>
                </p>
            <?php }
            } else {
        ?>
        <small>
            <?php // echo esc_html('Next Validation: ', 'campoal-tapo') . date_i18n('H:i - l, F j, Y', $license_status['nextValidation']); ?><br>
            <?php // echo esc_html('Schedule Event: ', 'campoal-tapo') . date_i18n('H:i - l, F j, Y', wp_next_scheduled('conikal_campoal_license_validity')); ?>
        </small>
        <?php  } ?>
    </p>
 <?php
}

function conikal_license_key_string_cb( $args ) {
 // get the value of the setting we've registered with register_setting()
 $options = get_option( 'conikal_license_key_string_option' );
 // output the field
 ?>
    <input id="title" type="text" name="conikal_license_key_string_option" size="55" value="<?php echo esc_attr($options); ?>">
    <p class="description">
        <?php _e( 'Enter a purchase code from your Envato\'s order or Conikal license key from <strong>My Account > License keys</strong>', 'campoal-tapo' ); ?>
    </p>
 <?php
}
 
/**
 * top level menu
 */
function conikal_campoal_license_options_page() {
    // add top level menu page
    add_submenu_page(
        'options-general.php', // top level menu page
        'Conikal License',
        'Conikal License Settings',
        'manage_options',
        'conikal-license',
        'conikal_campoal_license_options_page_html'
    );
}
 
/**
 * register our conikal_pdo_options_page to the admin_menu action hook
 */
add_action( 'admin_menu', 'conikal_campoal_license_options_page' );
 
/**
 * top level menu:
 * callback functions
 */
function conikal_campoal_license_options_page_html() {
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    // add error/update messages
 
    // check if the user have submitted the settings
    // wordpress will add the "settings-updated" $_GET parameter to the url
    if ( isset( $_GET['settings-updated'] ) ) {
        // $license_key_string = isset($_POST['conikal_license_key_string_option']) ? $_POST['conikal_license_key_string_option'] : '';
        $license_key_string = get_option( 'conikal_license_key_string_option', '' );
        $license = ConikalLicense();
        if (!empty($license_key_string)) {
            $license_status = $license->validate_status($license_key_string);

            if ( $license_status['is_valid'] && intval($license_status['data']['timesActivated']) < intval($license_status['data']['timesActivatedMax']) ) {
                // active license
                $license_activate = $license->activate($license_key_string);

                $activation_remaining = intval($license_activate['timesActivatedMax']) - intval($license_activate['timesActivated']);
                if (intval($activation_remaining) == 0) {
                    $message = __('The license has reached its activation limit: ', 'campoal-tapo') . $license_activate['timesActivated'] . '/' . $license_activate['timesActivatedMax'];
                } else {
                    $message = __('License key has been activated. Activations remaining: ', 'campoal-tapo') . $activation_remaining;
                }
            } elseif ($license_status['error']) {
                $message = $license_status['error'];
            } else {
                // $license_deactive = $license->deactivate($license_key_string);
                $message = __('The license has reached its activation limit: ', 'campoal-tapo') . $license_status['data']['timesActivated'] . '/' . $license_status['data']['timesActivatedMax'];
            }
        } else {
            $license_deactive = $license->deactivate($license_key_string);
            $message = __('License deactivated', 'campoal-tapo');
            delete_site_transient('conikal-license-notice-dismissed');
        }

        // add settings saved message with the class of "updated"
        add_settings_error( 'conikal_license_messages', 'conikal_license_messages', $message, 'updated' );
    }

    // show error/update messages
    settings_errors( 'conikal_license_messages' );
 ?>
    <div class="wrap">
        <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <form action="options.php" method="post">
 <?php
    // output security fields for the registered setting "campoal-tapo"
    settings_fields( 'conikal-license' );
    // output setting sections and their fields
    // (sections are registered for "campoal-tapo", each field is registered to a specific section)
    do_settings_sections( 'conikal-license' );
    // output save settings button
    submit_button( 'Activate License' );
 ?>
        </form>
    </div>
 <?php
}
?>