<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


 /**
 * Add meta box for user profile
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_user_meta_box( $meta_boxes ) {
	$meta_boxes[] = [
        'title'  => 'Supporter Info',
        'id'     => 'supporter',
        'type'   => 'user',
        'fields' => [
			[
                'id'   => 'user_type',
                'name' => 'User type',
                'type' => 'radio',
				'options' => array(
					'petitioner'        => esc_html__('Activist', 'campoal-tapo'),
					'organization'      => esc_html__('Organization', 'campoal-tapo'),
					'decisioner'   		=> esc_html__('Legislator', 'campoal-tapo'),
				),
            ],
			[
                'id'   => 'user_organization_name',
                'name' => 'Organization name',
                'type' => 'text',
            ],
            [
                'id'   => 'user_gender',
                'name' => 'Gender',
                'type' => 'select_advanced',
				'options' => array(
					'male'          => esc_html__('Male', 'campoal-tapo'),
					'female'        => esc_html__('Female', 'campoal-tapo'),
					'transgender'   => esc_html__('Transgender', 'campoal-tapo'),
					'gender_neutra' => esc_html__('Gender neutra', 'campoal-tapo'),
					'non_binary'    => esc_html__('Non binary', 'campoal-tapo'),
					'agender'       => esc_html__('Agender', 'campoal-tapo'),
					'pangender'     => esc_html__('Pangender', 'campoal-tapo'),
					'genderqueer'   => esc_html__('Genderqueer', 'campoal-tapo'),
					'two_spirit'    => esc_html__('Two-spirit', 'campoal-tapo'),
					'third_gender'  => esc_html__('Third gender', 'campoal-tapo'),
					'two_spirit'    => esc_html__('Two-spirit', 'campoal-tapo'),
				),
            ],
			[
                'id'   => 'user_birthday',
                'name' => 'Birthday',
                'type' => 'date',
				'js_options' => [
					'dateFormat'      => 'MM d, yy',
					'showButtonPanel' => false,
				],
				'inline'    => false,
				'timestamp' => false,
            ],
			[
                'id'   => 'user_phone_code',
                'name' => 'Phone Code',
                'type' => 'select_advanced',
				'options' => conikal_phone_codes(),
            ],
			[
                'id'   => 'user_phone',
                'name' => 'Phone number',
                'type' => 'tel',
            ],
            [
                'id'   => 'user_address',
                'name' => 'Address',
                'type' => 'text',
            ],
			[
                'id'   => 'user_neighborhood',
                'name' => 'Neighborhood',
                'type' => 'text',
            ],
			[
                'id'   => 'user_city',
                'name' => 'City',
                'type' => 'text',
            ],
			[
                'id'   => 'user_state',
                'name' => 'State',
                'type' => 'text',
            ],
			[
                'id'   => 'user_country',
                'name' => 'Country',
                'type' => 'text',
            ],
			[
                'id'   => 'user_lat',
                'name' => 'Latitude',
                'type' => 'text',
            ],
			[
                'id'   => 'user_lng',
                'name' => 'Longitude',
                'type' => 'text',
            ],
            [
                'id'   => 'user_zip',
                'name' => 'Zip code',
                'type' => 'text',
            ],
        ],
    ];
	
    return $meta_boxes;
}
add_action( 'rwmb_meta_boxes', 'conikal_user_meta_box' );


/**
 * Add meta box for petition post type
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_petition_meta_box( $meta_boxes ) {
	$prefix = 'petition_';

	/* START petition details */
	$meta_boxes[] = array(
		'id' => 'petition-details',
		'title' => esc_html__( 'Petition Details', 'campoal-tapo' ),
		'post_types' => array('petition'),
		'context' => 'advanced',
		'priority' => 'high',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'status',
				'name' => esc_html__( 'Petition Status', 'campoal-tapo' ),
				'type' => 'select',
				'placeholder' => esc_html__( 'Set a status', 'campoal-tapo' ),
				'options' => array(
					'0' => 'Open',
					'1' => 'Victory',
					'2' => 'Closed',
				),
				'std' => '0',
			),
			array(
				'id' => $prefix . 'increase',
				'name' => esc_html__( 'Auto Increase Percent', 'campoal-tapo' ),
				'type' => 'select',
				'options' => array(
					'0' => esc_html__( 'No Increase', 'campoal-tapo' ), 
					10 => '10%', 
					20 => '20%', 
					30 => '30%', 
					40 => '40%', 
					50 => '50%', 
					60 => '60%', 
					70 => '70%',
					80 => '80%', 
					90 => '90%', 
					100 => '100%', 
					150 => '150%', 
					200 => '200%', 
					300 => '300%', 
					500 => '500%'),
				'std' => '0',
			),
			array(
				'id' => $prefix . 'goal',
				'type' => 'number',
				'name' => esc_html__( 'Goal', 'campoal-tapo' ),
				'std' => '1000',
				'placeholder' => esc_html__( 'Set petition goal', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'sign',
				'type' => 'number',
				'name' => esc_html__( 'Signatures', 'campoal-tapo' ),
				'std' => '1',
				'placeholder' => esc_html__( 'Signatures of petition', 'campoal-tapo' ),
			),
			array(
			    'id'        => $prefix . 'citation_status',
			    'name'      => 'Citation status',
			    'type'      => 'switch',
			    'style'     => 'rounded',
			    'on_label'  => esc_html__( 'Show', 'campoal-tapo' ),
			    'off_label' => esc_html__( 'Hidden', 'campoal-tapo' ),
			    'std'		=> 0
			),
			array(
				'id' => $prefix . 'opinion_yes',
				'type' => 'number',
				'name' => esc_html__( 'Agree', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Number of agree citation', 'campoal-tapo' ),
				'std'		=> 0,
			),
			array(
				'id' => $prefix . 'opinion_no',
				'type' => 'number',
				'name' => esc_html__( 'Disagree', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Number of disagree citation', 'campoal-tapo' ),
				'std' => 0,
			),
			array(
				'id' => $prefix . 'sendinblue_list',
				'type' => 'number',
				'name' => esc_html__( 'SendinBlue list ID', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Set List ID', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'contribute',
				'type' => 'post',
				'post_type' => 'give_forms',
				'name' => esc_html__( 'Give Form ID', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Set Form ID', 'campoal-tapo' ),
				'field_type' => 'select_advanced',
			),
			array(
				'id' => $prefix . 'receiver',
				'type' => 'textarea',
				'name' => esc_html__( 'Receivers', 'campoal-tapo' ),
				'desc' => esc_html__( 'Separated by commas', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. Donald Trump, Mark Zuckerberg, Bill Gate', 'campoal-tapo' ),
				'rows' => 3,
			),
			array(
				'id' => $prefix . 'position',
				'type' => 'textarea',
				'name' => esc_html__( 'Positions', 'campoal-tapo' ),
				'desc' => esc_html__( 'Separated by commas', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. President of the United States, CEO of Facebook, Founder of Microsoft', 'campoal-tapo' ),
				'rows' => 3,
			),
			array(
				'id' => $prefix . 'decisionmakers',
				'type' => 'post',
				'multiple' => true, 
				'post_type' => 'decisionmakers',
				'name' => esc_html__( 'Decision makers', 'campoal-tapo' ),
				'desc' => esc_html__( 'Search and select one or multi person', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. 324, 442, 566, 7882', 'campoal-tapo' ),
				'field_type' => 'select_advanced',
			),
			array(
				'id' => $prefix . 'sign_button_label',
				'type' => 'text',
				'name' => esc_html__( 'Sign button label', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter custom button label', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'confirmation_page',
				'type' => 'post',
				'post_type' => 'page',
				'name' => esc_html__( 'Signature confirmation page', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Select a page that design for thanks to supporters', 'campoal-tapo' ),
				'field_type' => 'select_advanced',
			),
			array(
				'id' => $prefix . 'letter',
				'name' => esc_html__( 'Petition Letter', 'campoal-tapo' ),
				'type' => 'wysiwyg',
			),
		),
	);

	/* START petition location */
	$meta_boxes[] = array(
		'id' => 'petition-location',
		'title' => esc_html__( 'Petition Location', 'campoal-tapo' ),
		'post_types' => array('petition'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'address',
				'type' => 'text',
				'name' => esc_html__( 'Address', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter address', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'neighborhood',
				'type' => 'text',
				'name' => esc_html__( 'Neighborhood', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter neighborhood', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'city',
				'type' => 'text',
				'name' => esc_html__( 'City', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter city', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'state',
				'type' => 'text',
				'name' => esc_html__( 'State', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter county/state', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'zip',
				'type' => 'text',
				'name' => esc_html__( 'Zip Code', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter zip code', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'country',
				'type' => 'text',
				'name' => esc_html__( 'Country', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter county', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'lat',
				'type' => 'text',
				'name' => esc_html__( 'Latitude', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter latitude', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'lng',
				'type' => 'text',
				'name' => esc_html__( 'Longitude', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter longitude', 'campoal-tapo' ),
			),
		),
	);

	/* START petition media */
	$meta_boxes[] = array(
		'id' => 'petition-media',
		'title' => esc_html__( 'Petition Media', 'campoal-tapo' ),
		'post_types' => array('petition' ),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'video',
				'type' => 'oembed',
				'name' => esc_html__( 'Video URL', 'campoal-tapo' ),
				'desc' => esc_html__( 'oEmbed video by url from Youtube or Vimeo', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter video URL', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail', 'campoal-tapo' ),
				'desc' => esc_html__( 'Thumbnail of video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/maxresdefault.jpg', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb_small',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail small', 'campoal-tapo' ),
				'desc' => esc_html__( 'Small thumbnail for video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/hqdefault.jpg', 'campoal-tapo' ),
			),
		),
	);

	/* START petition location */
	$meta_boxes[] = array(
		'id' => 'petition-social',
		'title' => esc_html__( 'Petition Social Heading', 'campoal-tapo' ),
		'post_types' => array('petition'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'mail_subject',
				'type' => 'textarea',
				'name' => esc_html__( 'Mail subject', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom mail subject for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'mail',
				'type' => 'textarea',
				'name' => esc_html__( 'Mail', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom mail message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'facebook',
				'type' => 'textarea',
				'name' => esc_html__( 'Facebook', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Facebook heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'twitter',
				'type' => 'textarea',
				'name' => esc_html__( 'Twitter', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Tweet for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'telegram',
				'type' => 'textarea',
				'name' => esc_html__( 'Telegram', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Telegram message for petition', 'campoal-tapo' ),
			),
			// array(
			// 	'id' => $prefix . 'messenger',
			// 	'type' => 'textarea',
			// 	'name' => esc_html__( 'Messenger', 'campoal-tapo' ),
			// 	'placeholder' => esc_html__( 'Custom Messenger message for petition', 'campoal-tapo' ),
			// ),
			array(
				'id' => $prefix . 'whatsapp',
				'type' => 'textarea',
				'name' => esc_html__( 'Whatsapp', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Whatsapp message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'line',
				'type' => 'textarea',
				'name' => esc_html__( 'Line', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Line message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'linkedin',
				'type' => 'textarea',
				'name' => esc_html__( 'LinkedIn', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Telegram heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'tumblr',
				'type' => 'textarea',
				'name' => esc_html__( 'Tumblr', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Tumblr message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'pinterest',
				'type' => 'textarea',
				'name' => esc_html__( 'Pinterest', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Pinterest description for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reddit',
				'type' => 'textarea',
				'name' => esc_html__( 'Reddit', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Reddit heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'vk',
				'type' => 'textarea',
				'name' => esc_html__( 'Vk', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Vk heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'sms',
				'type' => 'textarea',
				'name' => esc_html__( 'SMS', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom SMS message for petition', 'campoal-tapo' ),
			),
		),
	);

	/* START petition updates */
	$meta_boxes[] = array(
		'id' => 'petition-updates',
		'title' => esc_html__( 'Petition Updates', 'campoal-tapo' ),
		'post_types' => array('petition'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'type' => 'custom_html',
				'callback' => 'conikal_petition_update_render'
			),
		),
	);


	/* START petition featured */
	$meta_boxes[] = array(
		'id' => 'petition-featured',
		'title' => esc_html__( 'Petition Featured', 'campoal-tapo' ),
		'post_types' => array('petition' ),
		'context' => 'side',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'featured',
				'name' => esc_html__( 'Petition Featured', 'campoal-tapo' ),
				'type' => 'checkbox',
				'desc' => esc_html__( 'Set as Featured', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'victory',
				'name' => esc_html__( 'Victory Featured', 'campoal-tapo' ),
				'type' => 'checkbox',
				'desc' => esc_html__( 'Set as Victory Featured', 'campoal-tapo' ),
			),
			array(
				'id' => 'custom_short_url',
				'type' => 'text',
				'name' => esc_html__( 'Short URL', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Short URL', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_petition_meta_box' );


/**
 * Add meta box for update post type
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_updates_meta_box( $meta_boxes ) {
	$prefix = 'update_';

	$meta_boxes[] = array(
		'id' => 'update-details',
		'title' => esc_html__( 'Update Detail', 'campoal-tapo' ),
		'post_types' => array('update' ),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'type',
				'name' => esc_html__( 'Update type', 'campoal-tapo' ),
				'type' => 'select',
				'placeholder' => esc_html__( 'Select an type', 'campoal-tapo' ),
				'options' => array(
					'update' => esc_html__('Update', 'campoal-tapo'),
					'featured' => esc_html__('Featured', 'campoal-tapo'),
					'responsive' => esc_html__('Responsive', 'campoal-tapo'),
					'victory' => esc_html__('Victory', 'campoal-tapo'),
				),
			),
			array(
				'id' => $prefix . 'post_id',
				'type' => 'post',
				'name' => esc_html__( 'Update Campaign ID', 'campoal-tapo' ),
				'desc' => esc_html__( 'Update for the specify campaign', 'campoal-tapo' ),
				'post_type' => array('petition', 'give_forms'),
				'field_type' => 'select_advanced',
				'placeholder' => esc_html__( 'Select a campaign', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'campaign_id',
				'type' => 'number',
				'name' => esc_html__( 'SendinBlue Campaign ID', 'campoal-tapo' ),
				'desc' => esc_html__( 'Email campaign ID for use this update content', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an campaign ID', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'media',
				'type' => 'url',
				'name' => esc_html__( 'URL Media Article', 'campoal-tapo' ),
				'desc' => esc_html__( 'URL of article related this update', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article URL', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'graph_title',
				'type' => 'text',
				'name' => esc_html__( 'Article title', 'campoal-tapo' ),
				'desc' => esc_html__( 'Title of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article title', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'graph_description',
				'type' => 'textarea',
				'name' => esc_html__( 'Article description', 'campoal-tapo' ),
				'desc' => esc_html__( 'Description of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article description', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'graph_image',
				'type' => 'url',
				'name' => esc_html__( 'Article image', 'campoal-tapo' ),
				'desc' => esc_html__( 'Image of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article image', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'graph_site',
				'type' => 'text',
				'name' => esc_html__( 'Article site name', 'campoal-tapo' ),
				'desc' => esc_html__( 'Site name of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article site name', 'campoal-tapo' ),
			),
		),
	);

	$meta_boxes[] = array(
		'id' => 'update-featured',
		'title' => esc_html__( 'Update Featured', 'campoal-tapo' ),
		'post_types' => array('update'),
		'context' => 'side',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'featured',
				'name' => esc_html__( 'Update Featured', 'campoal-tapo' ),
				'type' => 'checkbox',
				'desc' => esc_html__( 'Set as Featured', 'campoal-tapo' ),
			),
		),
	);

	/* START update media */
	$meta_boxes[] = array(
		'id' => 'update-media',
		'title' => esc_html__( 'Update Media', 'campoal-tapo' ),
		'post_types' => array('update'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'video',
				'type' => 'oembed',
				'name' => esc_html__( 'Video URL', 'campoal-tapo' ),
				'desc' => esc_html__( 'oEmbed video by url from Youtube or Vimeo', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter video URL', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail', 'campoal-tapo' ),
				'desc' => esc_html__( 'Thumbnail of video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/maxresdefault.jpg', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb_small',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail small', 'campoal-tapo' ),
				'desc' => esc_html__( 'Small thumbnail for video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/hqdefault.jpg', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_updates_meta_box' );


/**
 * Add meta box for citation post type
 *
 * @since Campoal Tapo 1.6.0
 */
function conikal_citation_meta_box( $meta_boxes ) {
	$prefix = 'citation_';

	$meta_boxes[] = array(
		'id' => 'citation-details',
		'title' => esc_html__( 'Citation Detail', 'campoal-tapo' ),
		'post_types' => array('citation'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'opinion',
				'name' => esc_html__( 'Citation opinion', 'campoal-tapo' ),
				'type' => 'select',
				'placeholder' => esc_html__( 'Select an opinion', 'campoal-tapo' ),
				'options' => array(
					'yes' => esc_html('Agree', 'campoal-tapo'),
					'no' => esc_html('Disagree', 'campoal-tapo'),
				),
			),
			array(
				'id' => $prefix . 'post_id',
				'type' => 'post',
				'name' => esc_html__( 'Citation Campaign ID', 'campoal-tapo' ),
				'desc' => esc_html__( 'Citation for the specify campaign', 'campoal-tapo' ),
				'post_type' => 'petition',
				'field_type' => 'select_advanced',
				'placeholder' => esc_html__( 'Select a campaign', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'vote_score',
				'type' => 'number',
				'name' => esc_html__( 'Vote score', 'campoal-tapo' ),
				'desc' => esc_html__( 'Vote score of this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an score number', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reference',
				'type' => 'url',
				'name' => esc_html__( 'URL Reference', 'campoal-tapo' ),
				'desc' => esc_html__( 'URL of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article URL', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reference_title',
				'type' => 'text',
				'name' => esc_html__( 'Reference title', 'campoal-tapo' ),
				'desc' => esc_html__( 'Title of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article title', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reference_description',
				'type' => 'textarea',
				'name' => esc_html__( 'Reference description', 'campoal-tapo' ),
				'desc' => esc_html__( 'Description of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article description', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reference_image',
				'type' => 'url',
				'name' => esc_html__( 'Reference image', 'campoal-tapo' ),
				'desc' => esc_html__( 'Image of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article image', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reference_site',
				'type' => 'text',
				'name' => esc_html__( 'Reference site name', 'campoal-tapo' ),
				'desc' => esc_html__( 'Site name of article related this citation', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter an article site name', 'campoal-tapo' ),
			),
		),
	);

	$meta_boxes[] = array(
		'id' => 'citation-featured',
		'title' => esc_html__( 'Citation Featured', 'campoal-tapo' ),
		'post_types' => array('citation'),
		'context' => 'side',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'featured',
				'name' => esc_html__( 'Citation Featured', 'campoal-tapo' ),
				'type' => 'checkbox',
				'desc' => esc_html__( 'Set as Featured', 'campoal-tapo' ),
			),
		),
	);

	/* START update media */
	$meta_boxes[] = array(
		'id' => 'citation-media',
		'title' => esc_html__( 'Citation Media', 'campoal-tapo' ),
		'post_types' => array('citation'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'video',
				'type' => 'oembed',
				'name' => esc_html__( 'Video URL', 'campoal-tapo' ),
				'desc' => esc_html__( 'oEmbed video by url from Youtube or Vimeo', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter video URL', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail', 'campoal-tapo' ),
				'desc' => esc_html__( 'Thumbnail of video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/maxresdefault.jpg', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb_small',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail small', 'campoal-tapo' ),
				'desc' => esc_html__( 'Small thumbnail for video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/hqdefault.jpg', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_citation_meta_box' );


/**
 * Add meta box for team post type
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_team_meta_box( $meta_boxes ) {
	$prefix = 'team_';

	$meta_boxes[] = array(
		'id' => 'member-details',
		'title' => esc_html__( 'Member Detail', 'campoal-tapo' ),
		'post_types' => array('team'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'position',
				'type' => 'text',
				'name' => esc_html__( 'Position', 'campoal-tapo' ),
				'desc' => esc_html__( 'Position in Company', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. Full Stack Developer', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'location',
				'type' => 'text',
				'name' => esc_html__( 'Location', 'campoal-tapo' ),
				'desc' => esc_html__( 'Location where this staff working', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. London', 'campoal-tapo' ),
			),
		),
	);

	$meta_boxes[] = array(
		'id' => 'social-link',
		'title' => esc_html__( 'Social Network Link', 'campoal-tapo' ),
		'post_types' => array('team' ),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'website',
				'type' => 'url',
				'name' => esc_html__( 'Website', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'facebook',
				'type' => 'url',
				'name' => esc_html__( 'Facebook', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'twitter',
				'type' => 'url',
				'name' => esc_html__( 'Twitter', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'linkedin',
				'type' => 'url',
				'name' => esc_html__( 'LinkedIn', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'behance',
				'type' => 'url',
				'name' => esc_html__( 'Behance', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'dribbble',
				'type' => 'url',
				'name' => esc_html__( 'Dribbble', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'flickr',
				'type' => 'url',
				'name' => esc_html__( 'Flickr', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'github',
				'type' => 'url',
				'name' => esc_html__( 'Github', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'instagram',
				'type' => 'url',
				'name' => esc_html__( 'Instagram', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'medium',
				'type' => 'url',
				'name' => esc_html__( 'Medium', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'pinterest',
				'type' => 'url',
				'name' => esc_html__( 'Pinterest', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reddit',
				'type' => 'url',
				'name' => esc_html__( 'Reddit', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'skype',
				'type' => 'url',
				'name' => esc_html__( 'Skype', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'tumblr',
				'type' => 'url',
				'name' => esc_html__( 'Tumblr', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'vimeo',
				'type' => 'url',
				'name' => esc_html__( 'Vimeo', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'vk',
				'type' => 'url',
				'name' => esc_html__( 'Vk', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'youtube',
				'type' => 'url',
				'name' => esc_html__( 'Youtube', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'weibo',
				'type' => 'url',
				'name' => esc_html__( 'Weibo', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'wechat',
				'type' => 'url',
				'name' => esc_html__( 'Wechat', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_team_meta_box' );

/**
 * Add meta box for testimonials post type
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_testimonials_meta_box( $meta_boxes ) {
	$prefix = 'testimonials_';

	$meta_boxes[] = array(
		'id' => 'testimonials-details',
		'title' => esc_html__( 'Testimonials Details', 'campoal-tapo' ),
		'post_types' => array('testimonials' ),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'job',
				'type' => 'text',
				'name' => esc_html__( 'Job Title', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. Graphic Designer', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'company',
				'type' => 'text',
				'name' => esc_html__( 'Company name', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. Apple, Inc.', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_testimonials_meta_box' );


/**
 * Add meta box for decision makwers post type
 *
 * @since Campoal Tapo 1.7.4
 */
function conikal_decision_maker_meta_box( $meta_boxes ) {
    $prefix = 'decisionmaker_';

    $meta_boxes[] = [
        'title'      => esc_html__( 'Decision Maker Details', 'campoal-tapo' ),
        'id'         => 'decisionmaker-details',
        'post_types' => ['decisionmakers'],
        'context'    => 'advanced',
        'priority'   => 'default',
        'autosave' => 'true',
        'fields'     => [
        	[
                'type' => 'checkbox',
                'id'   => $prefix . 'indentify_verified',
                'name' => esc_html__( 'Indentify verified', 'campoal-tapo' ),
                'desc' => esc_html__('Check the document was uploaded is correct.', 'campoal-tapo')
            ],
            [
                'type'        => 'select',
                'id'          => $prefix . 'indentify_type',
                'name'        => esc_html__( 'Type of identification', 'campoal-tapo' ),
                'desc'        => esc_html__( 'The type of document used to identify the account', 'campoal-tapo' ),
                'options'     => [
                    'national_id'    => esc_html__( 'National ID', 'campoal-tapo' ),
                    'driver_license' => esc_html__( 'Driver\'s license', 'campoal-tapo' ),
                    'passport'       => esc_html__( 'Passport', 'campoal-tapo' ),
                ],
                'placeholder' => esc_html__( 'Select a indentify type', 'campoal-tapo' ),
                'std'         => 'national_id',
            ],
            [
                'type'        => 'text',
                'id'          => $prefix . 'indentify_name',
                'name'        => esc_html__( 'Legal name', 'campoal-tapo' ),
                'desc'        => esc_html__( 'Legal name used on identification document', 'campoal-tapo' ),
                'placeholder' => esc_html__( 'Enter a legal name', 'campoal-tapo' ),
            ],
            [
                'type'        => 'text',
                'id'          => $prefix . 'indentify_id',
                'name'        => esc_html__( 'Indentify ID', 'campoal-tapo' ),
                'desc'        => esc_html__( 'ID used on identification document', 'campoal-tapo' ),
                'placeholder' => esc_html__( 'Enter a indentify ID', 'campoal-tapo' ),
            ],
            [
                'type'        => 'text',
                'id'          => $prefix . 'indentify_country_issue',
                'name'        => esc_html__( 'Country issued', 'campoal-tapo' ),
                'desc'        => esc_html__( 'The country issued this indentify document', 'campoal-tapo' ),
                'placeholder' => esc_html__( 'Enter a country name', 'campoal-tapo' ),
            ],
            [
                'type'             => 'image_advanced',
                'id'               => $prefix . 'indentify_frontside_photo',
                'name'             => esc_html__( 'Indentify front-side photo', 'campoal-tapo' ),
                'desc'             => esc_html__( 'Front side of indentify document photo', 'campoal-tapo' ),
                'max_file_uploads' => 1,
            ],
            [
                'type'             => 'image_advanced',
                'id'               => $prefix . 'indentify_backside_photo',
                'name'             => esc_html__( 'Indentify back-side photo', 'campoal-tapo' ),
                'desc'             => esc_html__( 'Back side of indentify document photo', 'campoal-tapo' ),
                'max_file_uploads' => 1,
            ],
            [
                'type'             => 'image_advanced',
                'id'               => $prefix . 'indentify_other_photo',
                'name'             => esc_html__( 'Other indentify document', 'campoal-tapo' ),
                'desc'             => esc_html__( 'Other indentify document photo', 'campoal-tapo' ),
                'max_file_uploads' => 1,
            ]
        ],
    ];

    return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_decision_maker_meta_box' );


/**
 * Add meta box for withdraw post type
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_withdraw_meta_box( $meta_boxes ) {
	$prefix = 'withdraw_';

	$meta_boxes[] = array(
		'id' => 'withdraw-detail',
		'title' => esc_html__( 'Withdraw Detail', 'campoal-tapo' ),
		'post_types' => array('withdraw'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'false',
		'fields' => array(
			array(
				'id' => $prefix . 'details',
				'type' => 'custom_html',
				'callback' => 'conikal_withdraw_detail_render'
			),
			array(
				'id' => $prefix . 'notes',
				'type' => 'textarea',
				'name' => esc_html__( 'Note', 'campoal-tapo' ),
				'desc' => esc_html__( 'Note for this withdraw', 'campoal-tapo' ),
				'rows' => 5,
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_withdraw_meta_box' );


/**
 * Add meta box for page
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_page_meta_box( $meta_boxes ) {

	$meta_boxes[] = array(
		'id' => 'page-sidebar',
		'title' => esc_html__( 'Page Settings', 'campoal-tapo' ),
		'post_types' => array('page'),
		'context' => 'side',
		'priority' => 'default',
		'autosave' => 'false',
		'fields' => array(
			array(
				'id' => 'campoal_page_sidebar',
				'type' => 'select',
				'name' => esc_html__( 'Sidebar', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Select an type', 'campoal-tapo' ),
				'options' => array(
					'default' => 'Default',
					'none' => 'No Sidebar', 
					'center' => 'Center', 
					'left' => 'Left Sidebar', 
					'right' => 'Right Sidebar'
				),
			),
			array(
				'id' => 'custom_short_url',
				'type' => 'text',
				'name' => esc_html__( 'Short URL', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Short URL', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_page_meta_box' );


/**
 * Add meta box for page
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_post_meta_box( $meta_boxes ) {
	$prefix = 'post_';

	/* START petition featured */
	$meta_boxes[] = array(
		'id' => 'post-featured',
		'title' => esc_html__( 'Post Featured', 'campoal-tapo' ),
		'post_types' => array('post' ),
		'context' => 'side',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'featured',
				'name' => esc_html__( 'Post Featured', 'campoal-tapo' ),
				'type' => 'checkbox',
				'desc' => esc_html__( 'Set as Featured', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'conikal_post_meta_box' );


/**
 * Add meta box for give form
 *
 * @since Campoal Tapo 1.1.7
 */
function conikal_give_meta_box( $meta_boxes ) {
	$prefix = '_give_';

	/* START form media */
	$meta_boxes[] = array(
		'id' => 'give-media',
		'title' => esc_html__( 'Campaign Media', 'campoal-tapo' ),
		'post_types' => array('give_forms'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'video',
				'type' => 'oembed',
				'name' => esc_html__( 'Video URL', 'campoal-tapo' ),
				'desc' => esc_html__( 'oEmbed video by url from Youtube or Vimeo', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter video URL', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail', 'campoal-tapo' ),
				'desc' => esc_html__( 'Thumbnail of video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/maxresdefault.jpg', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'thumb_small',
				'type' => 'url',
				'name' => esc_html__( 'Video thumbnail small', 'campoal-tapo' ),
				'desc' => esc_html__( 'Small thumbnail for video', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'eg. https://img.youtube.com/vi/Wf8My-FnplE/hqdefault.jpg', 'campoal-tapo' ),
			),
		),
	);

	/* START form location */
	$meta_boxes[] = array(
		'id' => 'give-location',
		'title' => esc_html__( 'Campaign Location', 'campoal-tapo' ),
		'post_types' => array('give_forms'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'address',
				'type' => 'text',
				'name' => esc_html__( 'Address', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter address', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'neighborhood',
				'type' => 'text',
				'name' => esc_html__( 'Neighborhood', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter neighborhood', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'city',
				'type' => 'text',
				'name' => esc_html__( 'City', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter city', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'state',
				'type' => 'text',
				'name' => esc_html__( 'State', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter county/state', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'zip',
				'type' => 'text',
				'name' => esc_html__( 'Zip Code', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter zip code', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'country',
				'type' => 'text',
				'name' => esc_html__( 'Country', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter county', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'lat',
				'type' => 'text',
				'name' => esc_html__( 'Latitude', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter latitude', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'lng',
				'type' => 'text',
				'name' => esc_html__( 'Longitude', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Enter longitude', 'campoal-tapo' ),
			),
		),
	);

	/* START petition location */
	$meta_boxes[] = array(
		'id' => 'give-social',
		'title' => esc_html__( 'Give Social Heading', 'campoal-tapo' ),
		'post_types' => array('give_forms'),
		'context' => 'advanced',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => $prefix . 'mail_subject',
				'type' => 'textarea',
				'name' => esc_html__( 'Mail subject', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom mail subject for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'mail',
				'type' => 'textarea',
				'name' => esc_html__( 'Mail', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom mail message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'facebook',
				'type' => 'textarea',
				'name' => esc_html__( 'Facebook', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Facebook heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'twitter',
				'type' => 'textarea',
				'name' => esc_html__( 'Twitter', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Tweet for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'telegram',
				'type' => 'textarea',
				'name' => esc_html__( 'Telegram', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Telegram message for petition', 'campoal-tapo' ),
			),
			// array(
			// 	'id' => $prefix . 'messenger',
			// 	'type' => 'textarea',
			// 	'name' => esc_html__( 'Messenger', 'campoal-tapo' ),
			// 	'placeholder' => esc_html__( 'Custom Messenger message for petition', 'campoal-tapo' ),
			// ),
			array(
				'id' => $prefix . 'whatsapp',
				'type' => 'textarea',
				'name' => esc_html__( 'Whatsapp', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Whatsapp message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'line',
				'type' => 'textarea',
				'name' => esc_html__( 'Line', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Line message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'linkedin',
				'type' => 'textarea',
				'name' => esc_html__( 'LinkedIn', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Telegram heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'tumblr',
				'type' => 'textarea',
				'name' => esc_html__( 'Tumblr', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Tumblr message for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'pinterest',
				'type' => 'textarea',
				'name' => esc_html__( 'Pinterest', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Pinterest description for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'reddit',
				'type' => 'textarea',
				'name' => esc_html__( 'Reddit', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Reddit heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'vk',
				'type' => 'textarea',
				'name' => esc_html__( 'Vk', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Vk heading for petition', 'campoal-tapo' ),
			),
			array(
				'id' => $prefix . 'sms',
				'type' => 'textarea',
				'name' => esc_html__( 'SMS', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom SMS message for petition', 'campoal-tapo' ),
			),
		),
	);

	/* START campaign featured */
	$meta_boxes[] = array(
		'id' => 'give-featured',
		'title' => esc_html__( 'Short URL', 'campoal-tapo' ),
		'post_types' => array('give_forms' ),
		'context' => 'side',
		'priority' => 'default',
		'autosave' => 'true',
		'fields' => array(
			array(
				'id' => 'custom_short_url',
				'type' => 'text',
				'name' => esc_html__( 'Short URL', 'campoal-tapo' ),
				'placeholder' => esc_html__( 'Custom Short URL', 'campoal-tapo' ),
			),
		),
	);

	return $meta_boxes;
}

add_filter( 'rwmb_meta_boxes', 'conikal_give_meta_box' );

?>