<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
**/


/**
 * Get user IP and date to save post view counter
 *
 * @since Campoal Tapo 1.6.0
 */
if( !function_exists('conikal_unique_post_visitors') ): 
    function conikal_unique_post_visitors() {
        check_ajax_referer('views_ajax_nonce', 'security');
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'visitors';

        $ip = conikal_get_client_ip();
        $date = current_time('mysql');

        // set post view count
        conikal_set_post_views($post_id);

        // get viewers list
        $visitors_list_key = 'post_' . $type . '_list';
        $visitors_list = get_post_meta($post_id, $visitors_list_key, true);
        if(empty($visitors_list)) {
            $visitors_list = array();
            delete_post_meta($post_id, $visitors_list_key);
            add_post_meta($post_id, $visitors_list_key, $visitors_list);
        }

        // check unique ip and update visistor list
        if (is_array($visitors_list) && array_key_exists($ip, $visitors_list) === false) {
            $visitors_list[$ip] = array('date' => $date);
            update_post_meta($post_id, $visitors_list_key, $visitors_list);
            conikal_set_post_views($post_id, $type);
            $number = conikal_get_post_views($post_id, $type, false);

            echo json_encode(array('status'=>true, 'number' => $number) );
            exit();
        } else {
            $number = conikal_get_post_views($post_id, $type, false);
            echo json_encode(array('status'=>false, 'number' => $number) );
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_unique_post_visitors', 'conikal_unique_post_visitors' );
add_action( 'wp_ajax_conikal_unique_post_visitors', 'conikal_unique_post_visitors' );


/**
 * Set post views number
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_set_post_views') ): 
    function conikal_set_post_views($post_id, $type = 'views') {
        $count_key = 'post_' . $type . '_count';
        $count = get_post_meta($post_id, $count_key, true);
        if($count == '') {
            $count = 1;
            delete_post_meta($post_id, $count_key);
            add_post_meta($post_id, $count_key, $count);
        } else {
            $count++;
            update_post_meta($post_id, $count_key, $count);
        }
    }
endif;


/**
 * Get post view number
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_get_post_views') ): 
    function conikal_get_post_views($post_id, $type = 'views', $global = true) {
        global $campoal_options;
        $counter_type = isset($campoal_options['conikal_view_counter_type_field']) ? $campoal_options['conikal_view_counter_type_field'] : 'views';
        if ($global == true) {
            $type = $counter_type;
        }

        $count_key = 'post_' . $type . '_count';
        $count = intval(get_post_meta($post_id, $count_key, true));
        if(empty($count)) {
            $count = 1;
            delete_post_meta($post_id, $count_key);
            add_post_meta($post_id, $count_key, $count);
            return $count;
        }

        return $count;
    }
endif;

?>