<?php

/**
 * Register petition custom post type
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_register_petition_type') ):
    function conikal_register_petition_type() {
        global $petition_config;

        // Registe petitio post type
        $labels = array(
            'name'                  => esc_html__('Petitions', 'campoal-tapo'),
            'singular_name'         => esc_html__('Petition', 'campoal-tapo'),
            'add_new'               => esc_html__('Add New Petition', 'campoal-tapo'),
            'add_new_item'          => esc_html__('Add Petition', 'campoal-tapo'),
            'edit'                  => esc_html__('Edit', 'campoal-tapo'),
            'edit_item'             => esc_html__('Edit Petition', 'campoal-tapo'),
            'new_item'              => esc_html__('New Petition', 'campoal-tapo'),
            'view'                  => esc_html__('View', 'campoal-tapo'),
            'view_item'             => esc_html__('View Petition', 'campoal-tapo'),
            'search_items'          => esc_html__('Search Petition', 'campoal-tapo'),
            'not_found'             => esc_html__('No Petition found', 'campoal-tapo'),
            'not_found_in_trash'    => esc_html__('No Petition found in Trash', 'campoal-tapo'),
            'parent'                => esc_html__('Parent Petition', 'campoal-tapo'),
        );

        $permalinks = get_option('conikal_permalink_settings');
        if(!$permalinks) $permalinks = array();

        $permalinks['petition_permalink_base'] = empty($permalinks['petition_permalink_base']) ? 'petition' : $permalinks['petition_permalink_base'];
        $permalinks['petition_category_taxonomy_base'] = empty($permalinks['petition_category_taxonomy_base']) ? 'cats' : $permalinks['petition_category_taxonomy_base'];
        $permalinks['petition_topics_taxonomy_base'] = empty($permalinks['petition_topics_taxonomy_base']) ? 'topics' : $permalinks['petition_topics_taxonomy_base'];

        $args = array(
            'labels'                => $labels,
            'public'                => true,
            'exclude_from_search '  => false,
            'has_archive'           => true,
            'rewrite'               => array('slug'=>_x($permalinks['petition_permalink_base'],'URL slug','campoal-tapo'), 'with_front'=>true),
            'show_in_rest'          => true,
            'supports'              => array('title', 'author', 'editor', 'thumbnail', 'comments', 'shortlinks'),
            'can_export'            => true,
            'menu_icon'             => 'dashicons-clipboard'
        );

        $args = apply_filters('avf_petition_cpt_args', $args);
        $petition_config['custom_post']['petition']['args'] = $args;

        register_post_type('petition', $args);

        // Register petition category taxonomy
        $petition_category_args = array(
            'labels' => array(
                'name'              => esc_html__('Petition Categories', 'campoal-tapo'),
                'add_new_item'      => esc_html__('Add New Petition Category', 'campoal-tapo'),
                'new_item_name'     => esc_html__('New Petition Category', 'campoal-tapo')
            ),
            'public'        => true,
            'show_ui'       => true,
            'hierarchical'  => true,
            'query_var'     => true,
            'rewrite'       => array('slug'=>_x($permalinks['petition_category_taxonomy_base'],'URL slug','campoal-tapo'), 'with_front'=>true),
            'show_in_rest'  => true,
        );
        register_taxonomy('petition_category', 'petition', $petition_category_args);

        $petition_config['custom_taxonomy']['petition']['petition_category']['args'] = $petition_category_args;

        // Register meta for category background image
        register_meta( 'petition_category', 'petition_category_image', array(
            'description'   => 'The background image show on category archive and shortcodes',
            'single'        => true,
            'show_in_rest'  => true,
        ));

        // Register petition topics taxonomy
        $petition_topics_args = array(
            'labels' => array(
                'name'              => esc_html__('Petition Topics', 'campoal-tapo'),
                'add_new_item'      => esc_html__('Add New Petition Topics', 'campoal-tapo'),
                'new_item_name'     => esc_html__('New Petition Topics', 'campoal-tapo')
            ),
            'public'        => true,
            'show_ui'       => true,
            'hierarchical'  => false,
            'query_var'     => true,
            'rewrite'       => array('slug'=>_x($permalinks['petition_topics_taxonomy_base'],'URL slug','campoal-tapo'), 'with_front'=>true),
            'show_in_rest'  => true,
        );
        register_taxonomy('petition_topics', 'petition', $petition_topics_args);

        $petition_config['custom_taxonomy']['petition']['petition_topics']['args'] = $petition_topics_args;
    }
endif;
add_action('init', 'conikal_register_petition_type');

if( !function_exists('conikal_insert_default_terms') ):
    function conikal_insert_default_terms() {
        conikal_register_petition_type();
        wp_insert_term('Environment', 'petition_category', $args = array());
        wp_insert_term('Technology', 'petition_category', $args = array());
        wp_insert_term('Education', 'petition_category', $args = array());
        wp_insert_term('Human rights', 'petition_topics', $args = array());
        wp_insert_term('Disabled rights', 'petition_topics', $args = array());
    }
endif;
register_activation_hook( __FILE__, 'conikal_insert_default_terms' );


if( !function_exists('conikal_petition_update_render') ):
    function conikal_petition_update_render($post) {
        global $post;
        wp_nonce_field(plugin_basename(__FILE__), 'petition_noncename');
        $mypost = $post->ID;
        $originalpost = $post;
        $update_list = '';

        $args = array(
            'posts_per_page' => -1,
            'post_type' => 'update',
            'post_status' => 'publish'
        );

        $args['meta_query'] = array('relation' => 'AND');

        if($mypost != '') {
            array_push($args['meta_query'], array(
                'key'     => 'update_post_id',
                'value'   => $mypost,
            ));
        }

        $query = new WP_Query($args);

        $updates = new WP_Query($args);

        while($updates->have_posts()) {
            $updates->the_post();
            $update_id = get_the_ID();
            $author_id = $updates->post_author;
            $status = get_post_status($update_id);
            $link = get_edit_post_link($update_id);
            $title = get_the_title($update_id);
            $excerpt = conikal_get_excerpt_by_id($update_id);
            $date = get_the_date('Y/m/d', $update_id);
            $petition_id =  get_post_meta($update_id, 'update_post_id', true);
            $media = get_post_meta($update_id, 'petition_media', true);
            $gallery = get_post_meta($update_id, 'petition_gallery', true);
            $images = conikal_get_gallery_images($gallery);
            $thumb_id = get_post_thumbnail_id($update_id);
            $thumbnail = wp_get_attachment_image_src($thumb_id, 'thumbnail', true);
            $thumb_video = get_post_meta($mypost, 'petition_thumb', true);
            $comments = wp_count_comments($update_id);
            $views = conikal_get_post_views($update_id);

            $update_list .= '<tr id="post-' . esc_html($update_id) . '" class="iedit author-self level-0 post-' . esc_html($update_id) . ' type-update status-publish hentry">';
            $update_list .= '<th class="title column-title has-row-actions column-primary page-title"><strong><a class="row-title" href="' . esc_url($link) . '">' . esc_html($title) . '</a></strong></th>';
            $update_list .= '<th width="50px" class="comments column-comments">' . ($comments->approved ? '<div class="post-com-count-wrapper"><span class="post-com-count post-com-count-approved" href="' . esc_url($link) . '"><span class="comment-count-approved">' . esc_html($comments->approved) . '</span></span></div>' : '—') . '</th>';
            $update_list .= '<th class="date column-date">' . esc_html($status) . '<br/><abbr title="' . esc_attr($date) .  '">' . esc_html($date) . '</abbr></th>';
            $update_list .= '<th class="view column-view">' . esc_html($views) . '</th>';
            $update_list .= '</tr>';
        }

        wp_reset_postdata();
        $post = $originalpost;

        print '
            <table class="wp-list-table widefat fixed striped posts">
                <thead>
                    <tr>
                        <td class="manage-column">' . esc_html__('Title', 'campoal-tapo') . '</td>
                        <td class="manage-column"><span><span class="vers comment-grey-bubble" title="' . esc_attr__('Comments', 'campoal-tapo') . '"><span class="screen-reader-text">' . esc_html__('Comments', 'campoal-tapo') . '</span></span></span></td>
                        <td class="manage-column">' . esc_html__('Date', 'campoal-tapo') . '</td>
                        <td class="manage-column">' . esc_html__('Views', 'campoal-tapo') . '</td>
                    </tr>
                </thead>
                <tbody>
                    ' . $update_list . '
                </tbody>
            </table>';
    }
endif;

if( !function_exists('conikal_substr45') ):
    function conikal_substr45($string) {
        return substr($string, 0, 45);
    }
endif;

if( !function_exists('conikal_change_petition_default_title') ):
    function conikal_change_petition_default_title($title){
        $screen = get_current_screen();
        if ('petition' == $screen->post_type) {
            $title = esc_html__('Enter petition title here', 'campoal-tapo');
        }
        return $title;
    }
endif;
add_filter('enter_title_here', 'conikal_change_petition_default_title');


/**
 * Add custom image petition category form
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_petition_category_add_meta_field') ):
function conikal_petition_category_add_meta_field() {
    wp_nonce_field( basename( __FILE__ ), 'petition_category_nonce' );

    print '
        <div class="form-field petition-category-image-wrap">
            <label for="petition-category-image">' . esc_html__('Category background image', 'campoal-tapo') . '</label>
            <input type="text" name="petition_category_image" id="petition-category-image" value="" />
            <input id="categoryImageBtn" type="button"  class="button" value="' . esc_attr__('Browse...', 'campoal-tapo') . '" />
            <p class="description">' . esc_html__('The background image show on category archive and shortcodes', 'campoal-tapo') . '</p>
        </div>
    ';
}
endif;
add_action( 'petition_category_add_form_fields', 'conikal_petition_category_add_meta_field' );


if( !function_exists('conikal_petition_category_edit_meta_field') ):
function conikal_petition_category_edit_meta_field($term) {
    wp_nonce_field( basename( __FILE__ ), 'petition_category_nonce' );
    $image = get_term_meta($term->term_id, 'petition_category_image', true);

    print '
    <tr class="form-field petition-category-image-wrap">
        <th scope="row"><label for="petition-category-image">' . esc_html__('Category background image', 'campoal-tapo') . '</label></th>
        <td>
            <input type="text" name="petition_category_image" id="petition-category-image" value="' . ($image ? esc_attr($image) : '') . '" />
            <input id="categoryImageBtn" type="button"  class="button" value="' . esc_attr__('Browse...', 'campoal-tapo') . '" />
            <p class="description">' . esc_html__('The background image show on category archive and shortcodes', 'campoal-tapo') . '</p>
        </td>
    </tr>';
}
endif;
add_action( 'petition_category_edit_form_fields', 'conikal_petition_category_edit_meta_field' );


if( !function_exists('conikal_save_petition_category_image') ):
function conikal_save_petition_category_image( $term_id ) {

    if ( ! isset( $_POST['petition_category_nonce'] ) || ! wp_verify_nonce( $_POST['petition_category_nonce'], basename( __FILE__ ) ) ) {
        return;
    }

    $old_image = get_term_meta($term_id, 'petition_category_image', true);
    $new_image = isset( $_POST['petition_category_image'] ) ? sanitize_text_field( $_POST['petition_category_image'] ) : '';

    if ( $old_image && '' === $new_image ) {
        delete_term_meta($term_id, 'petition_category_image');
    } else if ( $old_image !== $new_image ) {
        update_term_meta($term_id, 'petition_category_image', $new_image);
    }
}
endif;
add_action( 'edit_petition_category',   'conikal_save_petition_category_image' );
add_action( 'create_petition_category', 'conikal_save_petition_category_image' );


/**
 * Add custom image petition topics form
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_petition_topics_add_meta_field') ):
function conikal_petition_topics_add_meta_field() {
    wp_nonce_field( basename( __FILE__ ), 'petition_topics_nonce' );

    print '
        <div class="form-field petition-topics-image-wrap">
            <label for="petition-topics-image">' . esc_html__('Topics background images', 'campoal-tapo') . '</label>
            <input type="text" name="petition_topics_image" id="petition-topics-image" value="" />
            <input id="topicsImageBtn" type="button"  class="button" value="' . esc_attr__('Browse...', 'campoal-tapo') . '" />
            <p class="description">' . esc_html__('The background image show on topics archive and shortcodes', 'campoal-tapo') . '</p>
        </div>
    ';
}
endif;
add_action( 'petition_topics_add_form_fields', 'conikal_petition_topics_add_meta_field' );


if( !function_exists('conikal_petition_topics_edit_meta_field') ):
function conikal_petition_topics_edit_meta_field($term) {
    wp_nonce_field( basename( __FILE__ ), 'petition_topics_nonce' );
    $image = get_term_meta($term->term_id, 'petition_topics_image', true);

    print '
    <tr class="form-field petition-topics-image-wrap">
        <th scope="row"><label for="petition-topics-image">' . esc_html__('Topics background images', 'campoal-tapo') . '</label></th>
        <td>
            <input type="text" name="petition_topics_image" id="petition-topics-image" value="' . ($image ? esc_attr($image) : '') . '" />
            <input id="topicsImageBtn" type="button"  class="button" value="' . esc_attr__('Browse...', 'campoal-tapo') . '" />
            <p class="description">' . esc_html__('The background image show on topics archive and shortcodes', 'campoal-tapo') . '</p>
        </td>
    </tr>';
}
endif;
add_action( 'petition_topics_edit_form_fields', 'conikal_petition_topics_edit_meta_field' );


if( !function_exists('conikal_save_petition_topics_image') ):
function conikal_save_petition_topics_image( $term_id ) {

    if ( ! isset( $_POST['petition_topics_nonce'] ) || ! wp_verify_nonce( $_POST['petition_topics_nonce'], basename( __FILE__ ) ) ) {
        return;
    }

    $old_image = get_term_meta($term_id, 'petition_topics_image', true);
    $new_image = isset( $_POST['petition_topics_image'] ) ? sanitize_text_field( $_POST['petition_topics_image'] ) : '';

    if ( $old_image && '' === $new_image ) {
        delete_term_meta($term_id, 'petition_topics_image');
    } else if ( $old_image !== $new_image ) {
        update_term_meta($term_id, 'petition_topics_image', $new_image);
    }
}
endif;
add_action( 'edit_petition_topics',   'conikal_save_petition_topics_image' );
add_action( 'create_petition_topics', 'conikal_save_petition_topics_image' );


/**
 * Add custom column for petition post type in admin
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_petition_custom_column') ):
    function conikal_petition_custom_column($defaults) {
        $defaults['post_views'] = esc_html__('Views','campoal-tapo');
        $defaults['supporters'] = esc_html__('Supporters','campoal-tapo');
        $defaults['goal'] = esc_html__('Goal','campoal-tapo');
        $defaults['status'] = esc_html__('Status','campoal-tapo');
        return $defaults;
    }
endif;
add_filter('manage_petition_posts_columns', 'conikal_petition_custom_column');

if( !function_exists('conikal_petition_custom_column_views') ):
    function conikal_petition_custom_column_views($column_name, $id) {
        if ($column_name === 'post_views') {
            $post_views = conikal_get_post_views(get_the_ID(), '');
            echo $post_views ? number_format_i18n($post_views) : '';
        }
        if ($column_name === 'supporters') {
            $supporters = get_post_meta(get_the_ID(), 'petition_sign', true);
            echo $supporters ? number_format_i18n($supporters) : '';
        }
        if ($column_name === 'goal') {
            $goal = get_post_meta(get_the_ID(), 'petition_goal', true);
            echo $goal ? number_format_i18n($goal) : '';
        }
        if ($column_name === 'status') {
            $status = get_post_meta(get_the_ID(), 'petition_status', true);
            $goal = get_post_meta(get_the_ID(), 'petition_goal', true);
            $sign = get_post_meta(get_the_ID(), 'petition_sign', true);
            // petition status label
            switch ($status) {
                case 0:
                    $status_label = esc_html__('Open', 'campoal-tapo');
                    $status_color = 'green';
                    if ($sign >= $goal) {
                        $status_label = esc_html__('Victory', 'campoal-tapo');
                        $status_color = 'red';
                    }
                    break;

                case 1:
                    $status_label = esc_html__('Victory', 'campoal-tapo');
                    $status_color = 'red';
                    break;

                default:
                    $status_label = esc_html__('Close', 'campoal-tapo');
                    $status_color = 'grey';
                    break;
            }

            echo '<span class="ui ' . esc_html($status_color) . ' empty circular label"></span> ' . esc_html($status_label);
        }
    }
endif;
add_action('manage_petition_posts_custom_column', 'conikal_petition_custom_column_views', 5, 2);

?>