<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
* Get social meta post
*
* @since Campoal Tapo 1.0.0
*/
if (!function_exists('conikal_social_meta')) :    
    function conikal_social_meta($petition_id = false) {
        global $post;

        if(is_singular('petition')) {
            $id             = $post->ID;
            $title          = get_the_title($id);
            $link           = get_permalink($id);
            $short_link     = wp_get_shortlink($id);
            $heading        = get_post_meta($id, 'petition_heading', true);
            $title          = ($heading != '' ? $heading : $title);
            $gallery        = get_post_meta($id, 'petition_gallery', true);
            $images         = conikal_get_gallery_images($gallery);
            $video_thumb    = get_post_meta($id, 'petition_thumb', true);
            $thumbnail      = isset($gallery) && count($images) >= 2 ? $images[1] : $video_thumb;
        } else if (is_singular('update')) {
            $update_id      = $post->ID;           
            $id             = get_post_meta($update_id, 'update_post_id', true);
            $title          = get_the_title($id);
            $link           = get_permalink($id);
            $short_link     = wp_get_shortlink($id);
            $heading        = get_post_meta($id, 'petition_heading', true);
            $title          = ($heading != '' ? $heading : $title);
            $gallery        = get_post_meta($id, 'petition_gallery', true);
            $images         = conikal_get_gallery_images($gallery);
            $video_thumb    = get_post_meta($id, 'petition_thumb', true);
            $thumbnail      = isset($gallery) && count($images) >= 2 ? $images[1] : $video_thumb;
        } else if (is_singular('citation')) {
            $citation_id    = $post->ID;         
            $id             = get_post_meta($citation_id, 'citation_post_id', true);
            $title          = get_the_title($id);
            $link           = get_permalink($id);
            $short_link     = wp_get_shortlink($id);
            $heading        = get_post_meta($id, 'petition_heading', true);
            $title          = ($heading != '' ? $heading : $title);
            $gallery        = get_post_meta($id, 'petition_gallery', true);
            $images         = conikal_get_gallery_images($gallery);
            $video_thumb    = get_post_meta($id, 'petition_thumb', true);
            $thumbnail      = isset($gallery) && count($images) >= 2 ? $images[1] : $video_thumb;
        } else if (is_singular('give_forms')) {
            $give_prefix    = '_give_';
            $id             = $post->ID;
            $title          = get_the_title($id);
            $link           = get_permalink($id);
            $short_link     = wp_get_shortlink($id);
            $excerpt        = conikal_get_excerpt_by_id($id);
            $gallery        = get_post_meta($id, $give_prefix . 'gallery', true);
            $images         = conikal_get_gallery_images($gallery);
            $video_thumb    = get_post_meta($id, $give_prefix . 'thumb', true);
            $thumbnail      = isset($gallery) && count($images) >= 2 ? $images[1] : $video_thumb;
        } else if (is_single()) {
            $id             = $post->ID;
            $title          = get_the_title($id);
            $link           = get_permalink($id);
            $short_link     = wp_get_shortlink($id);
            $thumbnail      = wp_get_attachment_image_src( get_post_thumbnail_id( $id ), 'single-post-thumbnail' );
            $thumbnail      = ($thumbnail ? $thumbnail[0] : '');
        } else if (!empty($petition_id)) {
            if (is_page($petition_id)) {
                $id             = $petition_id;
                $title          = get_the_title($id);
                $link           = get_permalink($id);
                $short_link     = wp_get_shortlink($id);
                $thumbnail      = wp_get_attachment_image_src( get_post_thumbnail_id( $id ), 'single-post-thumbnail' );
                $thumbnail      = ($thumbnail ? $thumbnail[0] : '');
            } else {
                $id             = $petition_id;
                $title          = get_the_title($id);
                $link           = get_permalink($id);
                $short_link     = wp_get_shortlink($id);
                $heading        = get_post_meta($id, 'petition_heading', true);
                $title          = ($heading != '' ? $heading : $title);
                $gallery        = get_post_meta($id, 'petition_gallery', true);
                $images         = conikal_get_gallery_images($gallery);
                $video_thumb    = get_post_meta($id, 'petition_thumb', true);
                $thumbnail      = isset($gallery) && count($images) >= 2 ? $images[1] : $video_thumb;
            }
        }

        if (!empty($id)) {
            $social_meta = array(
                'id'            => $id,
                'petition_id'   => $petition_id,
                'title'         => $title,
                'link'          => $link,
                'short_link'    => $short_link,
                'thumbnail'     => $thumbnail,
            );

            return (object) $social_meta;
        } else {
            return false;
        }
    }
endif;

/**
* Social custom heading for petition
*
* @since Campoal Tapo 2.3.5
*/
if (!function_exists('conikal_social_custom_heading')) :    
    function conikal_social_custom_heading($petition_id) {
        // get custom social heading
        $social_keys = array(
            'mail',
            'facebook',
            'twitter',
            'telegram',
            'messenger',
            'whatsapp',
            'line',
            'linkedin',
            'tumblr',
            'pinterest',
            'reddit',
            'vk',
            'sms',
        );

        $social_headings = array();

        foreach ($social_keys as $social) {
            $custom_heading         = get_post_meta($petition_id, 'petition_' . $social, true);
            $petition_title         = get_the_title($petition_id);
            if (!empty($custom_heading)) {
                $social_headings[$social] = $custom_heading;
            } else {
                $social_headings[$social] = $petition_title;
            }
        }

        return $social_headings;
    }
endif;


/**
* Social buttons data
*
* @since Campoal Tapo 1.0.0
*/
if (!function_exists('conikal_social_buttons_data')) :    
    function conikal_social_buttons_data($social_meta, $fb_app = false, $phone_code = '0', $petition_id = false, $custom_share_link = false) {
        $mail_sharing_subject   = conikal_user_email_sharing((!empty($petition_id) ? $petition_id : $social_meta->id), 'subject', $custom_share_link);
        $mail_sharing_content   = conikal_user_email_sharing((!empty($petition_id) ? $petition_id : $social_meta->id), 'message', $custom_share_link);

        $custom_heading = conikal_social_custom_heading((!empty($petition_id) ? $petition_id : $social_meta->id));

        // Get share counter 
        $share_counter = conikal_get_share_counter(!empty($petition_id) ? $petition_id : $social_meta->id);
        
        $social_buttons = array(
            'mail'          => array(
                'name'  => esc_html__('Mail', 'campoal-tapo'),
                'label' => esc_html__('Send an Email', 'campoal-tapo'),
                'link'  => 'mailto://?subject=' . esc_attr($mail_sharing_subject) . '&body=' . esc_attr($mail_sharing_content),
                'popup' => array(
                    'height'    => '300',
                    'width'     => '600'
                ),
                'classes' => 'send-email',
                'icon'    => 'envelope icon',
                'onclick' => false,
                'counter' => $share_counter['mail']
            ),
            'gmail'          => array(
                'name'  => esc_html__('Gmail', 'campoal-tapo'),
                'label' => esc_html__('Send via Gmail', 'campoal-tapo'),
                'link'  => 'https://mail.google.com/mail/u/0/?to&su=' . esc_attr($mail_sharing_subject) . '&body=' . esc_attr($mail_sharing_content) . '&bcc&cc&fs=1&tf=cm',
                'popup' => array(
                    'height'    => '446',
                    'width'     => '780'
                ),
                'classes' => 'send-gmail',
                'icon'    => 'google icon',
                'onclick' => true,
                'counter' => $share_counter['gmail']
            ),
            'facebook'      => array(
                'name'  => esc_html__('Facebook', 'campoal-tapo'),
                'label' => esc_html__('Share on Facebook', 'campoal-tapo'),
                'link'  => (!empty($fb_app) ? 'javascript:void(0)' : 'https://www.facebook.com/sharer/sharer.php?u=' . urlencode($social_meta->link) . '&t=' . urlencode($custom_heading['facebook']) ),
                'popup' => array(
                    'height'    => '745',
                    'width'     => '575'
                ),
                'classes' => 'share-facebook',
                'icon'    => 'facebook f icon',
                'onclick' => (!empty($fb_app) ? false : true),
                'counter' => $share_counter['facebook']
            ),
            'twitter'      => array(
                'name'  => esc_html__('Twitter', 'campoal-tapo'),
                'label' => esc_html__('Share on Twitter', 'campoal-tapo'),
                'link'  => '//twitter.com/share?url=' . $social_meta->link . '&text=' . urlencode($custom_heading['twitter']),
                'popup' => array(
                    'height'    => '500',
                    'width'     => '600'
                ),
                'classes' => 'share-twitter',
                'icon'    => 'twitter icon',
                'onclick' => true,
                'counter' => $share_counter['twitter']
            ),
            'embed-widget' => array(
                'name'  => esc_html__('Embed', 'campoal-tapo'),
                'label' => esc_html__('Embed Campaign', 'campoal-tapo'),
                'link'  => 'javascript:void(0)',
                'popup' => array(
                    'height'    => '300',
                    'width'     => '600'
                ),
                'classes' => 'embed-campaign',
                'icon'    => 'code icon',
                'onclick' => false,
                'counter' => $share_counter['embed-widget']
            ),
            'telegram'      => array(
                'name'  => esc_html__('Telegram', 'campoal-tapo'),
                'label' => esc_html__('Send via Telegram', 'campoal-tapo'),
                'link'  => '//t.me/share/url?url=' . $social_meta->link . '&text=' . urlencode($custom_heading['telegram']),
                'popup' => array(
                    'height'    => '500',
                    'width'     => '600'
                ),
                'classes' => 'send-telegram',
                'icon'    => 'telegram plane icon',
                'onclick' => true,
                'counter' => $share_counter['telegram']
            ),
            'messenger'      => array(
                'name'  => esc_html__('Messager', 'campoal-tapo'),
                'label' => esc_html__('Send via Messenger', 'campoal-tapo'),
                'link'  => (!empty($fb_app) ? 'javascript:void(0)' : 'http://www.facebook.com/dialog/send?app_id=' . urlencode($fb_app) . '&amp;link=' . urlencode($social_meta->link) . '&amp;redirect_uri=' . urlencode($social_meta->link) ),
                'popup' => array(
                    'height'    => '300',
                    'width'     => '600'
                ),
                'classes' => 'send-message',
                'icon'    => 'facebook messenger icon',
                'onclick' => (!empty($fb_app) ? false : true),
                'counter' => $share_counter['messenger']
            ),
            'whatsapp'      => array(
                'name'  => esc_html__('WhatsApp', 'campoal-tapo'),
                'label' => esc_html__('Send via WhatsApp', 'campoal-tapo'),
                'link'  => '//api.whatsapp.com/send?phone=&text=' . urlencode($custom_heading['whatsapp']) . '&nbsp;' . $social_meta->link,
                'popup' => array(
                    'height'    => '600',
                    'width'     => '600'
                ),
                'classes' => 'send-whatsapp',
                'icon'    => 'whatsapp icon',
                'onclick' => true,
                'counter' => $share_counter['whatsapp']
            ),
            'line'      => array(
                'name'  => esc_html__('Line', 'campoal-tapo'),
                'label' => esc_html__('Send via Line', 'campoal-tapo'),
                'link'  => '//line.me/R/msg/text/?' . $social_meta->link . '&title=' . urlencode($custom_heading['line']),
                'popup' => array(
                    'height'    => '350',
                    'width'     => '600'
                ),
                'classes' => 'send-line',
                'icon'    => 'linechat icon',
                'onclick' => true,
                'counter' => $share_counter['line']
            ),
            'linkedin'      => array(
                'name'  => esc_html__('LinkedIn', 'campoal-tapo'),
                'label' => esc_html__('Share on LinkedIn', 'campoal-tapo'),
                'link'  => '//www.linkedin.com/shareArticle?mini=true&url=' . $social_meta->link . '&title=' . urlencode($custom_heading['linkedin']),
                'popup' => array(
                    'height'    => '350',
                    'width'     => '600'
                ),
                'classes' => 'share-linkedin',
                'icon'    => 'linkedin icon',
                'onclick' => true,
                'counter' => $share_counter['linkedin']
            ),
            'tumblr'      => array(
                'name'  => esc_html__('Tumblr', 'campoal-tapo'),
                'label' => esc_html__('Share on Tumblr', 'campoal-tapo'),
                'link'  => '//www.tumblr.com/share/link?url=' . $social_meta->link,
                'popup' => array(
                    'height'    => '600',
                    'width'     => '600'
                ),
                'classes' => 'share-tumblr',
                'icon'    => 'tumblr icon',
                'onclick' => true,
                'counter' => $share_counter['tumblr']
            ),
            'pinterest'      => array(
                'name'  => esc_html__('Pinterest', 'campoal-tapo'),
                'label' => esc_html__('Pin this Post', 'campoal-tapo'),
                'link'  => '//pinterest.com/pin/create/bookmarklet/?media=' . $social_meta->thumbnail . '&url=' . esc_url($social_meta->link) . '&description=' . urlencode($custom_heading['pinterest']),
                'popup' => array(
                    'height'    => '600',
                    'width'     => '600'
                ),
                'classes' => 'share-pinterest',
                'icon'    => 'pinterest icon',
                'onclick' => true,
                'counter' => $share_counter['pinterest']
            ),
            'reddit'      => array(
                'name'  => esc_html__('Reddit', 'campoal-tapo'),
                'label' => esc_html__('Share on Reddit', 'campoal-tapo'),
                'link'  => '//reddit.com/submit?url=' . $social_meta->link . '&title=' . urlencode($custom_heading['reddit']),
                'popup' => array(
                    'height'    => '626',
                    'width'     => '600'
                ),
                'classes' => 'share-reddit',
                'icon'    => 'reddit icon',
                'onclick' => true,
                'counter' => $share_counter['reddit']
            ),
            'vk'      => array(
                'name'  => esc_html__('Vk', 'campoal-tapo'),
                'label' => esc_html__('Share on Vk', 'campoal-tapo'),
                'link'  => '//vk.com/share.php?url=' . $social_meta->link . '&title=' . urlencode($custom_heading['vk']),
                'popup' => array(
                    'height'    => '400',
                    'width'     => '600'
                ),
                'classes' => 'share-vk',
                'icon'    => 'vk icon',
                'onclick' => true,
                'counter' => $share_counter['vk']
            ),
            'sms'      => array(
                'name'  => esc_html__('Message', 'campoal-tapo'),
                'label' => esc_html__('Send a Message', 'campoal-tapo'),
                'link'  => 'sms://' . $phone_code . '&body=' . urlencode($custom_heading['sms']) . '-' . $social_meta->short_link,
                'popup' => array(
                    'height'    => '300',
                    'width'     => '600'
                ),
                'classes' => 'send-telephone',
                'icon'    => 'comment outline icon',
                'onclick' => false,
                'counter' => $share_counter['sms']
            ),
        );

        return $social_buttons;
    }
endif;

/**
* Add social button sharing on post left sticky
*
* @since Campoal Tapo 1.0.0
*/
function conikal_post_left_sticky($output) {
    global $post;
    $post_id = $post->ID;
    $post_title = get_the_title($post_id);
    $post_url = get_permalink($post_id);
    $post_excerpt = conikal_get_excerpt_by_id($post_id, 30);
    $post_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'single-post-thumbnail' );

    $output = '<div class="ui vertical icon secondary menu">
                <a href="' . esc_url('mailto://?subject=' . esc_html($post_title) . '&body=' . urlencode(wp_get_shortlink($post_id))) . '" class="item font large" id="send-mail" data-content="' . esc_attr__('Send an Email' ,'campoal-tapo') . '" data-variation="small" data-position="right center">
                    <i class="mail icon"></i>
                </a>
                <a href="//www.facebook.com/sharer/sharer.php?u=' . esc_url($post_url) . '"
                                    onclick="' . "javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=300,width=600');return false;" . '" class="item font large" data-content="' . esc_attr__('Share on Facebook' ,'campoal-tapo') . '" data-variation="small" data-position="right center">
                    <i class="facebook f icon"></i>
                </a>
                <a href="//twitter.com/share?url=' . esc_url($post_url) . '&text=' . urlencode($post_title) . '"
                    onclick="' . "javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=300,width=600');return false;" . '" class="item font font large" data-content="' . esc_attr__('Share on Twitter' ,'campoal-tapo') . '" data-variation="small" data-position="right center">
                    <i class="twitter icon"></i>
                </a>
            </div>';
    return $output;
}
add_filter( 'conikal_post_left_sticky', 'conikal_post_left_sticky');

/**
 *****************************************************************************
 * Custom post excerpt length and get excerpt by post id
 *****************************************************************************
 */
if( !function_exists('conikal_get_excerpt_by_id') ): 
    function conikal_get_excerpt_by_id($post_id, $excerpt_length = 30, $content = '') {
        global $post;
        $post_id = empty($post_id) ? $post->ID : $post_id;

        if (has_excerpt($post_id)) {
            $the_excerpt    = get_the_excerpt($post_id);
        } else if ($content != '') {
            $the_excerpt = strip_tags(strip_shortcodes($content));
        } else {
            $the_post = get_post($post_id);
            $the_excerpt = $the_post->post_content;
            $the_excerpt = strip_tags(strip_shortcodes($the_excerpt));
        }
        $words = explode(' ', $the_excerpt, $excerpt_length + 1);

        if (count($words) > $excerpt_length) {
            array_pop($words);
            array_push($words, '...');
        }
        $the_excerpt = implode(' ', $words);

        return $the_excerpt;
    }
endif;

/**
 *****************************************************************************
 * Custom social sharing title
 *****************************************************************************
 */
function conikal_custom_heading_title($id, $template = '') {
    global $current_user;
    global $campoal_options;

    $default_heading_template = isset($campoal_options['conikal_default_heading_template_field']) ? $campoal_options['conikal_default_heading_template_field'] : '';

    $post_title = get_the_title($id);
    $post_heading = get_post_meta($id, 'petition_heading', true);

    // custom heading variable
    $vars_find = array(
        '{title}',
        '{supporter_name}',
        '{supporter_number}',
        '{decision_maker}',
        '{author_name}',
    );

    $supporter_name = is_user_logged_in() ? $current_user->display_name : esc_html__('Anonymouse', 'campoal-tapo');
    $supporter_number = conikal_get_supporter_donors_number($id);
    $author_id = get_post_field ('post_author', $id);
    $author_name = get_the_author_meta('display_name', $author_id);
    $decision_maker = conikal_get_decistion_makers($id, true, 1);

    $vars_replace = array(
        $post_title,
        $supporter_name,
        $supporter_number->sign,
        $decision_maker,
        $author_name
    );

    if (!empty($post_heading)) {
        $result = str_replace($vars_find, $vars_replace, $post_heading);
    } else if (!empty($template)) {
        $result = str_replace($vars_find, $vars_replace, $template);
    } else if (!empty($default_heading_template)) {
        $result = str_replace($vars_find, $vars_replace, $default_heading_template);
    } else {
        $result = $post_title;
    }

    return $result;
}

/**
 *****************************************************************************
 * Social Meta Tags
 *****************************************************************************
 */
add_action( 'wp_head', 'conikal_header_meta_tags' );
function conikal_header_meta_tags() {
    global $campoal_options;
    global $post;
    
    $fb_app_id = isset($campoal_options['conikal_fb_id_field']) ? $campoal_options['conikal_fb_id_field'] : '';
    $google_login = isset($campoal_options['conikal_google_login_field']) ? $campoal_options['conikal_google_login_field'] : 0;
    $google_client_id = isset($campoal_options['conikal_google_id_field']) ? $campoal_options['conikal_google_id_field'] : '';
    $google_client_secret = isset($campoal_options['conikal_google_secret_field']) ? $campoal_options['conikal_google_secret_field'] : '';
    $twitter_username = isset($campoal_options['conikal_twitter_username_field']) ? $campoal_options['conikal_twitter_username_field'] : '';
    $ads_banner = isset($campoal_options['conikal_ads_banner_field']) ? $campoal_options['conikal_ads_banner_field'] : 0;
    $adsense_publish_id = isset($campoal_options['conikal_adsense_publish_id_field']) ? $campoal_options['conikal_adsense_publish_id_field'] : '';

    if ($google_login == 1 && $google_client_id != '') {
        print '
            <meta name="google-signin-scope" content="profile email">
            <meta name="google-signin-client_id" content="' . esc_attr($google_client_id) . '" />
            <meta name="google-signin-requestvisibleactions" content="//schema.org/AddAction" />
            <meta name="google-signin-cookiepolicy" content="single_host_origin" />
        ';
    }

    if(is_single() && have_posts()) { 
        $fb_post_id = $post->ID;
        $fb_post_image = wp_get_attachment_image_src( get_post_thumbnail_id( $fb_post_id ), 'single-post-thumbnail' );
        $fb_post_excerpt = conikal_get_excerpt_by_id($fb_post_id);
        $fb_video_thumb = get_post_meta($fb_post_id, 'petition_thumb', true);
        if (get_post_type($fb_post_id) == 'petition') {
            $fb_post_title = conikal_custom_heading_title($fb_post_id);
        } else {
            $fb_post_title =get_the_title($fb_post_id);
        }

        if (is_singular('give_forms')) {
            $fb_video_thumb = get_post_meta($fb_post_id, '_give_thumb', true);
        }

        print '
            <meta property="fb:app_id" content="' . esc_attr($fb_app_id) . '"/>
            <meta property="og:url" content="' . get_permalink($fb_post_id) . '" />
            <meta property="og:title" content="' . esc_attr($fb_post_title) . '" />
            <meta property="og:description" content="' . esc_attr($fb_post_excerpt) . '" />
            <meta property="og:image" content="' . ($fb_post_image ? esc_url($fb_post_image[0]) : $fb_video_thumb) . '" />
            <meta property="og:image:alt" content="' . ($fb_post_image ? esc_attr($fb_post_title) : '') . '" />
            <meta name="twitter:title" content="' . esc_attr($fb_post_title) . '">
            <meta name="twitter:description" content="' . esc_attr($fb_post_excerpt) . '">
            <meta name="twitter:image" content="' . ($fb_post_image ? esc_url($fb_post_image[0]) : $fb_video_thumb) . '">
            <meta name="twitter:image:alt" content="' . esc_attr($fb_post_title) . '">
            <meta name="twitter:site" content="@' . esc_attr($twitter_username) . '">
            <meta name="twitter:card" content="summary_large_image">
        ';
    }

    if ( $ads_banner && !empty($adsense_publish_id) ) {
        print '<script data-ad-client="ca-' . esc_attr($adsense_publish_id) . '" async src="https://pagead2.googlesyndication.com/pagead/js/adsbygoogle.js"></script>';
    }

}

/****************************************
 * Add social button after post content
 *****************************************/
if (!function_exists('conikal_social_button_after_post_content')) :    
    function conikal_social_button_after_post_content($content, $aligment = 'right'){
        if (is_singular('post')) {
            global $post;
            global $campoal_options;

            $sortable_default = array(
                'mail'          => true,
                'facebook'      => true,
                'twitter'       => true,
                'telegram'      => true,
                'embed'         => true,
                'messenger'     => true,
                'whatsapp'      => true,
                'line'          => true,
                'linkedin'      => true,
                'tumblr'        => true,
                'pinterest'     => true,
                'reddit'        => true,
                'vk'            => true,
                'message'       => true,
            );

            $embed_code = isset($campoal_options['conikal_embed_code_field']) ? $campoal_options['conikal_embed_code_field'] : 0;
            $social_buttons_sortable = isset($campoal_options['conikal_social_buttons_sortable_field']) ? $campoal_options['conikal_social_buttons_sortable_field'] : $sortable_default;
            $share_button_position = isset($campoal_options['conikal_post_share_button_position_field']) ? $campoal_options['conikal_post_share_button_position_field'] : 'bottom';

            // Hide buttons
            if ( in_array($share_button_position, array('hidden', 'header')) && $aligment != 'none' ) {
                return $content;
            }

            // Get social meta
            $social_meta = conikal_social_meta();

            // Get social button data
            $social_buttons = conikal_social_buttons_data($social_meta);
            unset($social_buttons['embed']);

            // column button
            $share_column_number = 4;
            $share_column_class  = 'six';
            if (wp_is_mobile()) {
                $share_column_number = 3;
                $share_column_class  = 'five';
            }

            $share_classes = 'social-share';
            $button_classes = 'basic icon circular small button';
            
            if ($aligment != 'none') {
            $content .= '<div class="clearfix"></div><div class="ui section divider"></div>
            <div class="ui ' . esc_attr($share_classes) . '">
            <div class="ui grid">
                <div class="eight wide mobile eight wide tablet eight wide computer column social-share">';
            }
                    $i = 1;
                    foreach ($social_buttons_sortable as $social => $status) {
                        if ($status && $i <= $share_column_number && array_key_exists($social, $social_buttons)) {
                            $button_data = $social_buttons[$social];

                                $content .= '<a href="' . ($button_data['onclick'] ? esc_attr($button_data['link']) : esc_attr($button_data['link'])) . '" 
                                    class="ui ' . esc_attr($button_classes) . ' ' . esc_attr(in_array($social, array('facebook', 'messenger')) ? '' : 'share-button-counter ') . esc_attr($button_data['classes']) . '" 
                                    id="' . esc_attr($social . '-share-button' . $social_meta->id) . '"
                                    data-social="' . esc_attr($social) . '" 
                                    data-id="' . esc_attr($social_meta->id) . '"';

                                if ($button_data['onclick']) {
                                    $content .= 'onclick="' . "javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=" . esc_attr($button_data['popup']['height']) . ",width=" . esc_attr($button_data['popup']['width']) . "');return false;" . '" ';
                                }
                                    $content .= 'data-content="' . esc_attr($button_data['label']) . sprintf(esc_html__(' (%s)', 'campoal-tapo'), esc_attr($button_data['counter'])) . '" 
                                    data-variation="small" 
                                    data-position="top center"
                                    data-id="' . esc_attr($social_meta->id) . '">
                                        <i class="' . esc_attr($button_data['icon']) . '"></i>
                                    </a>';
                        }
                        $i++;
                    }

                        $content .= '<div class="ui icon top right pointing dropdown ' . esc_attr($button_classes) . ' more-share">
                            <i class="ellipsis horizontal icon"></i>
                            <div class="menu">';

                                    $i_dropdown = 1;
                                    foreach ($social_buttons_sortable as $social => $status) {
                                        if ($status && $i_dropdown > $share_column_number && array_key_exists($social, $social_buttons)) {
                                            $button_data = $social_buttons[$social];
                                            $content .= '<a href="' . ($button_data['onclick'] ? esc_attr($button_data['link']) : esc_attr($button_data['link'])) . '" 
                                                    class="item ' . esc_attr(in_array($social, array('facebook', 'messenger')) ? '' : 'share-button-counter ') . esc_attr($button_data['classes']) . '" 
                                                    id="' . esc_attr($social . '-share-button' . $social_meta->id) . '"
                                                    data-social="' . esc_attr($social) . '" 
                                                    data-id="' . esc_attr($social_meta->id) . '"';

                                            if ($button_data['onclick']) {
                                                $content .= 'onclick="' . "javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=" . esc_attr($button_data['popup']['height']) . ",width=" . esc_attr($button_data['popup']['width']) . "');return false;" . '" ';
                                            }
                                                $content .= ' data-id="' . esc_attr($social_meta->id) . '">
                                                        <i class="' . esc_attr($button_data['icon']) . '"></i>
                                                        ' . esc_attr($button_data['name']) . '
                                                        <span id="' . esc_attr($social) . '-share-counter' . esc_attr($social_meta->id) . '">' . sprintf(esc_html__(' (%s)', 'campoal-tapo'), esc_html( $button_data['counter']) ) . '</span>
                                                </a>';

                                        }
                                        $i_dropdown++;
                                    }
                        $content .= '</div>
                    </div>';
            if ($aligment != 'none') {
            $content .= '
                </div>
                <div class="eight wide mobile eight wide tablet eight wide computer right aligned column">
                    <div class="facebook-like-button">
                        <div class="fb-like" data-href="' . get_permalink($post->ID) . '" data-layout="button_count" data-action="like" data-size="large" data-show-faces="false" data-share="true"></div>
                    </div>
                </div>
                </div>
            </div>';
            }

        wp_nonce_field('share_ajax_nonce', 'securityShare' . ($post->ID), true);
        }

        return $content;
    }
endif;
add_filter( "the_content", "conikal_social_button_after_post_content", 12 );


?>