<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Get supporter numbers
 *
 * @since Campoal Tapo 1.6.5
 */
if (!function_exists('conikal_get_supporter_number')) :
    function conikal_get_supporter_number($id, $round = false) {
        if (empty($id)) {
            return;
        }

        $goal               = get_post_meta($id, 'petition_goal', true);
        $goal_format        = conikal_format_number('%!,0i', $goal, $round);

        $sign_num           = get_post_meta($id, 'petition_sign', true);
        $sign_num           = isset($sign_num) ? intval($sign_num) : 0;
        $sign_num_format    = conikal_format_number('%!,0i', $sign_num, $round);

        $sign_needed        = intval($goal) - intval($sign_num);
        $sign_needed_format = conikal_format_number('%!,0i', $sign_needed, $round);

        $sign_text          = _n('%s supporter', '%s supporters', $sign_num, 'campoal-tapo');

        $results = (object) array(
            'goal'          => $goal,
            'sign'          => $sign_num,
            'needed'        => $sign_needed,
            'goal_format'   => $goal_format,
            'sign_format'   => $sign_num_format,
            'needed_format' => $sign_needed_format,
            'text'          => $sign_text,
            'label'         => sprintf($sign_text, $sign_num_format),
        );

        return $results;
    }
endif;


/**
 * Get supporter number or donors number
 *
 * @since Campoal Tapo 1.6.5
 */
if (!function_exists('conikal_get_supporter_donors_number')) :
    function conikal_get_supporter_donors_number($id, $type = 'supporter', $round = false) {
		// get fundraising mode setting
		$fundraising_mode 	= conikal_fundraising_mode_setting($id);
		$give_prefix        = '_give_';
		$post_type 			= get_post_type($id);

        if ($fundraising_mode || $type == 'donor') {
            // get form option
			if ( $post_type == 'petition' ) {
				$form_id = get_post_meta($id, 'petition_contribute', true);
				$contribute_approve = get_post_status($form_id);
				if ($contribute_approve != 'publish') {
					$form_id = '';
				}
			} else if ($post_type == 'give_forms') {
				$form_id = $id;
			} else {
				$form_id = '';
			}
            
            if (class_exists('Give') && $form_id) {
                $goal           = get_post_meta($id, 'petition_goal', true);
                $sign_num       = give_get_form_sales_stats($form_id);
				$goal_option    = get_post_meta($form_id, $give_prefix . 'goal_option', true);
                $sign_needed    = intval($goal) - intval($sign_num);
                // $label = __('%s donors', 'campoal-tapo');

				$supporters_num = conikal_get_supporter_number($id, $round);

				$raised_number      = give_get_form_earnings_stats( $form_id );
                $raised_format      = give_currency_filter( give_format_amount( $raised_number, array( 'sanitize' => false ) ) );

				$goal_number 	= $supporters_num->goal;
				$goal_format 	= $supporters_num->goal_format;
				$needed_number 	= $supporters_num->needed;
				$needed_format 	= $supporters_num->needed_format;
				
				if (give_is_setting_enabled( $goal_option )) {

					$progress_stats     = give_goal_progress_stats( $form_id );
					$goal_number        = ($progress_stats['raw_goal'] != 0 ? $progress_stats['raw_goal'] : $goal);
					$goal_format        = give_currency_filter( give_format_amount( $goal_number, array( 'sanitize' => false ) ) );
					$progress_format  	= $progress_stats['format'];

					if ($progress_format == 'percentage') {
						$raised_number = $progress_stats['raw_actual'];
						$raised_format = $progress_stats['actual'];
					}
					
					$needed_number      = intval($goal_number) - intval($raised_number);
					$needed_format      = give_currency_filter( give_format_amount( $needed_number, array( 'sanitize' => false ) ) );
				}

                $text = __('%s raised', 'campoal-tapo');

                $results = (object) array(
                    'goal'          => $goal_number,
                    'sign'          => $raised_number,
                    'needed'        => $needed_number,
                    'goal_format'   => $goal_format,
                    'sign_format'   => $raised_format,
                    'needed_format' => $needed_format,
                    'text'          => $text,
                    'label'         => sprintf($text, $raised_format),
                );
            } else {
                $results = conikal_get_supporter_number($id, $round);
            }
        } else {
            $results = conikal_get_supporter_number($id, $round);
        }

        return $results;
    }
endif;


/**
 * Get list of supporters
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_supporters_list_data')) :
	function conikal_supporters_list_data($petition_id = false, $pagination = false, $comment = false) {
		if (empty($petition_id)) {
			return false;
		}

		global $campoal_options;

		if (empty($pagination)) {
			$pagination = isset($campoal_options['conikal_recent_supporters_donors_field']) ? $campoal_options['conikal_recent_supporters_donors_field'] : 10;
		}

		// get supporters from petition
		$supporters = get_post_meta($petition_id, 'petition_users', true);

		if (empty($supporters)) {
			return false;
		}
		
		// check and remove user not exist
		/*
		if (isset($supporters) && $supporters != '') {
			foreach ($supporters as $user_id => $supporter) { 
				$user = get_userdata($user_id);
				if ($user === false) {
					// destroy a signature
					unset($supporters[$user_id]);
				}
			}
		} else {
			return false;
			exit();
		} */

		// update signature then remove not exist user
		// update_post_meta($petition_id, 'petition_users', $supporters);

		// reverse array and pagination
        $supporters = array_reverse($supporters);
        $supporters = array_slice($supporters, 0, $pagination);

        //get user dedails
        $list_supporters = array();
		if (!empty($supporters)) :
			foreach ($supporters as $user_id => $supporter) { 
				$user 			= get_userdata($supporter['user_id']);
				$anonymous 		= array_key_exists('anonymous', $supporter) ? $supporter['anonymous'] : 0;
				$comment_id 	= isset($supporter['comment_id']) ? $supporter['comment_id'] : false;

				// lazy load placeholder
				$lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

				if ($user) {
					$user_id 			= $user->ID;
					$user_name 			= $user->display_name;
					$user_link 			= get_author_posts_url($user_id);
					$user_address 		= get_user_meta($user_id, 'user_address', true);
					$user_neigborhood 	= get_user_meta($user_id, 'user_neigborhood', true);
					$user_city 			= get_user_meta($user_id, 'user_city', true);
					$user_state 		= get_user_meta($user_id, 'user_state', true);
					$user_country 		= get_user_meta($user_id, 'user_country', true);
					$user_lat 			= get_user_meta($user_id, 'user_lat', true);
					$user_lng 			= get_user_meta($user_id, 'user_lng', true);
					$user_avatar 		= conikal_get_avatar_url( $user_id, array('size' => 64) );
					$user_avatar_retina = conikal_get_avatar_url( $user_id, array('size' => 128) );

					if ($user_country || $user_state || $user_city) {
						$user_location = esc_attr($user_city ? $user_city . ', ' : '') . esc_attr($user_state ? $user_state . ', ' : '') . esc_attr($user_country ? $user_country : '');
					} else {
						$user_location = esc_html__('Somewhere', 'campoal-tapo');
					}
					
					if ($anonymous == 1) {
						$user_avatar 		= conikal_get_avatar_url( 0, array('size' => 64) );
						$user_avatar_retina = conikal_get_avatar_url( 0, array('size' => 128) );
						$user_name 			= esc_html__('Anonymous', 'campoal-tapo');
						$user_link 			= '#';
					}

					$sign_date 			= strtotime($supporter['date'], current_time('timestamp'));
					$sign_date_format 	= date_i18n(get_option('date_format'), $sign_date);
					$sign_date_human 	= sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff($sign_date, current_time('timestamp')));

					if (wp_is_mobile()) {
						$subheading_label = sprintf(esc_html__('Signed this petition %2$s', 'campoal-tapo'), $user_location, $sign_date_human);
					} else {
						$subheading_label = sprintf(esc_html__('From %1$s signed this petition %2$s', 'campoal-tapo'), $user_location, $sign_date_human);
					}

					$supporter_detail = array(
						'user_id' 				=> $user_id, 
						'user_name'  			=> $user_name,
						'user_avatar' 			=> $user_avatar,
						'user_avatar_retina'	=> $user_avatar_retina,
						'user_avatar_lazy' 		=> $lazy_placeholder_avatar,
						'user_link' 			=> $user_link,
						'user_address' 			=> $user_address,
						'user_neigborhood' 		=> $user_neigborhood,
						'user_city' 			=> $user_city, 
						'user_state' 			=> $user_state,
						'user_country' 			=> $user_country,
						'user_lat' 				=> $user_lat,
						'user_lng' 				=> $user_lng,
						'user_location'			=> $user_location,
						'subheading_label' 		=> $subheading_label,
						'sign_date'				=> $sign_date,
						'sign_date_format'		=> $sign_date_format,
						'sign_date_human'		=> $sign_date_human,
						'comment_id'			=> $comment_id,
					);

					if (!empty($comment)) {
						// get supporter comment
						$supporter_comment = (!empty($comment_id) ? get_comment($comment_id) : false);
						$supporter_detail['comment_content'] = !empty($supporter_comment) ? $supporter_comment->comment_content : false;
					}

					// add support to supporters list
					array_push($list_supporters, $supporter_detail);
				}
			}
		endif;

		if (!empty($list_supporters)) {
			return $list_supporters;
		} else {
			return false;
		}
	}
endif;


/**
 * Get list of supporters
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_supporters_list')) :
	function conikal_supporters_list($petition_id = false) {
		check_ajax_referer('supporters_list_ajax_nonce', 'security');
		$post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
		$user_id = isset($_POST['user']) ? sanitize_text_field($_POST['user']) : '';

		// check if post id exits will instead petition id
		if ($post_id != '') {
			$petition_id = $post_id;
		}

		$list_supporters = conikal_supporters_list_data($petition_id);

        // return result suppoerters list by json or object
        if (!empty($list_supporters) && $post_id != '') {
        	echo json_encode( array('status' => true, 'users' => $list_supporters, 'message' => esc_html__('The supporters loaded successfully.', 'campoal-tapo')) );
            exit();
        } else if(!empty($list_supporters)) {
        	return $list_supporters;
        	exit();
        } else {
        	echo json_encode( array('status' => false, 'users' => $list_supporters, 'message' => esc_html__('No found supporters.', 'campoal-tapo')) );
            exit();
        }
	}
endif;
add_action( 'wp_ajax_nopriv_conikal_supporters_list', 'conikal_supporters_list' );
add_action( 'wp_ajax_conikal_supporters_list', 'conikal_supporters_list' );


/**
 * Get list of donors
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_donors_list_data')) :
	function conikal_donors_list_data($petition_id = false, $pagination = false) {
		if (empty($petition_id)) {
			return false;
		}

		global $campoal_options;

		if (empty($pagination)) {
			$pagination = isset($campoal_options['conikal_recent_supporters_donors_field']) ? $campoal_options['conikal_recent_supporters_donors_field'] : 10;
		}

		// get form id
		if (get_post_type($petition_id) == 'petition') {
			$form_id = get_post_meta($petition_id, 'petition_contribute', true);
		} else {
			$form_id = $petition_id;
		}

	    $contribute_approve = get_post_status($form_id);
	    if ($contribute_approve != 'publish') {
	        $form_id = '';
	    }

		// get donation with form id
		if(isset($form_id) && $form_id != '' && function_exists('give_get_payments')) {
	        $args = array(
	            'number' 		=> $pagination,
	            'status'     	=> 'publish',
	            'give_forms' 	=> array($form_id),
	            'order' 		=> 'DESC'
	        );
	        $donations = give_get_payments( $args );
	    } else {
	    	$donations = false;
	    }

        //get user dedails
        $list_donors = array();
        if (!empty($donations)) :
	        foreach ($donations as $donation) { 
	            $customer_id 	= give_get_payment_donor_id( $donation->ID );
		        $customer    	= new Give_Customer( $customer_id );
		        $user 			= get_user_by('ID', $customer->user_id);

		        $payment    			= new Give_Payment( $donation->ID );
        		$payment_date 			= strtotime($payment->date, current_time('timestamp'));
				$payment_date_format 	= date_i18n(get_option('date_format'), $payment_date);
               	$payment_date_human		= sprintf(esc_html__('%s ago', 'campoal-tapo'), human_time_diff($payment_date, current_time('timestamp')));
				$payment_total			= give_format_amount($payment->total, array( 'sanitize' => false ));
				$payment_total_format 	= give_currency_filter(give_format_amount($payment->total, array( 'sanitize' => false )));
				$payment_gateway 		= give_get_gateway_admin_label(give_get_payment_gateway(  $payment->ID ));

				// lazy load placeholder
				$lazy_placeholder_avatar = conikal_lazy_load_placeholder('avatar');

	            if ($user) {
	                $user_id 			= $user->ID;
	                $user_name 			= $user->display_name;
	                $user_link 			= get_author_posts_url($user_id);
	                $user_address 		= get_user_meta($user_id, 'user_address', true);
	                $user_neigborhood 	= get_user_meta($user_id, 'user_neigborhood', true);
	                $user_city 			= get_user_meta($user_id, 'user_city', true);
	                $user_state 		= get_user_meta($user_id, 'user_state', true);
	                $user_country 		= get_user_meta($user_id, 'user_country', true);
	                $user_lat 			= get_user_meta($user_id, 'user_lat', true);
	                $user_lng 			= get_user_meta($user_id, 'user_lng', true);
	                $user_avatar 		= conikal_get_avatar_url( $user_id, array('size' => 64) );
					$user_avatar_retina = conikal_get_avatar_url( $user_id, array('size' => 128) );
				} else {
					$user_id 			= $customer->user_id;
					$user_name 			= $customer->name;
					$user_link 			= '';
					$user_address 		= '';
					$user_neigborhood 	= '';
					$user_city 			= '';
					$user_state 		= '';
					$user_country 		= '';
					$user_lat 			= '';
					$user_lng 			= '';
					$user_avatar 		= conikal_get_avatar_url( 0, array('size' => 64) );
					$user_avatar_retina = conikal_get_avatar_url( 0, array('size' => 128) );
				}

				if ($user_country || $user_state || $user_city) {
					$user_location 	= esc_attr($user_city ? $user_city . ', ' : '') . esc_attr($user_state ? $user_state . ', ' : '') . esc_attr($user_country ? $user_country : '');
				} else {
					$user_location 	= ($user) ? esc_html__('Somewhere', 'campoal-tapo') : esc_html__('Guest', 'campoal-tapo');
				}

				if (wp_is_mobile()) {
					$subheading_label = sprintf(esc_html__('%2$s via %3$s %4$s', 'campoal-tapo'), $user_location, $payment_total_format, $payment_gateway, $payment_date_human);
				} else {
					$subheading_label = sprintf(esc_html__('From %1$s donated %2$s via %3$s %4$s', 'campoal-tapo'), $user_location, $payment_total_format, $payment_gateway, $payment_date_human);
				}

				// add customers to array list
				$donor_detail = array(
					'user_id' 				=> $user_id, 
					'user_name'  			=> $user_name,
					'user_avatar' 			=> $user_avatar,
					'user_avatar_retina' 	=> $user_avatar_retina,
					'user_avatar_lazy' 		=> $lazy_placeholder_avatar,
					'user_link' 			=> $user_link,
					'user_address' 			=> $user_address,
					'user_neigborhood' 		=> $user_neigborhood,
					'user_city' 			=> $user_city, 
					'user_state' 			=> $user_state,
					'user_country' 			=> $user_country,
					'user_lat' 				=> $user_lat,
					'user_lng' 				=> $user_lng,
					'user_location'			=> $user_location,
					'subheading_label' 		=> $subheading_label,
					'sign_date'				=> $payment_date,
					'sign_date_format'		=> $payment_date_format,
					'sign_date_human'		=> $payment_date_human,
					'payment_total'			=> $payment_total,
					'payment_total_format' 	=> $payment_total_format,
					'payment_gateway'		=> $payment_gateway,
				);
				array_push($list_donors, $donor_detail);
	        }
	    endif;

		return $list_donors;
	}
endif;

/**
 * Get list of donors
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_donors_list')) :
	function conikal_donors_list() {
		check_ajax_referer('supporters_list_ajax_nonce', 'security');
		
		$post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
		$user_id = isset($_POST['user']) ? sanitize_text_field($_POST['user']) : '';

		// check if post id exits will instead petition id
		if ($post_id != '') {
			$petition_id = $post_id;
		}

		$list_donors = conikal_donors_list_data($petition_id);

        // return result suppoerters list by json or object
        if (!empty($list_donors) && $post_id != '') {
        	echo json_encode( array('status' => true, 'users' => $list_donors, 'message' => esc_html__('The donors loaded successfully.', 'campoal-tapo')) );
            exit();
        } else if(!empty($list_donors)) {
        	return $list_donors;
        } else {
        	echo json_encode( array('status' => false, 'users' => $list_donors, 'message' => esc_html__('No donors found.', 'campoal-tapo')) );
            exit();
        }
	}
endif;
add_action( 'wp_ajax_nopriv_conikal_donors_list', 'conikal_donors_list' );
add_action( 'wp_ajax_conikal_donors_list', 'conikal_donors_list' );

?>