<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Recent petition widget
 *
 * @since Campoal Tapo 1.0.0
 */
class Recent_Petitions_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'recent_petitions_sidebar', 'description' => 'Recently petitions.');
        $control_ops = array('id_base' => 'recent_petitions_widget');
        parent::__construct('recent_petitions_widget', 'Campoal Recently', $widget_ops, $control_ops);
    }

    function form($instance) {
        $defaults = array(
            'title' => '',
            'limit' => ''
        );
        $instance = wp_parse_args((array) $instance, $defaults); ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('title')) ?>"><?php esc_html_e('Title', 'campoal-tapo') ?>:</label>
                <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')) ?>" name="<?php echo esc_attr($this->get_field_name('title')) ?>" value="<?php echo esc_attr($instance['title']) ?>" />
            </p>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('limit')) ?>"><?php esc_html_e('Number of petitions to show', 'campoal-tapo') ?>:</label>
                <input type="text" size="3" id="<?php echo esc_attr($this->get_field_id('limit')) ?>" name="<?php echo esc_attr($this->get_field_name('limit')) ?>" value="<?php echo esc_attr($instance['limit']) ?>" />
            </p>
    <?php }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['limit'] = sanitize_text_field($new_instance['limit']);

        if(function_exists('icl_register_string')) {
            icl_register_string('conikal_recent_petitions_widget', 'recent_petitions_widget_title', sanitize_text_field($new_instance['title']));
            icl_register_string('conikal_recent_petitions_widget', 'recent_petitions_widget_limit', sanitize_text_field($new_instance['limit']));
        }

        return $instance;
    }

    function widget($args, $instance) {
        global $campoal_options;
        
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        if ($title) {
            echo wp_kses_post($before_title) . esc_html($title) . wp_kses_post($after_title);
        }

        if ($instance['limit'] && $instance['limit'] != '') {
            $limit = $instance['limit'];
        } else {
            $limit = 4;
        }

        $args = array(
            'posts_per_page'   => $instance['limit'],
            'post_type'        => 'petition',
            'orderby'          => 'post_date',
            'order'            => 'DESC',
            'post_status'      => 'publish' );

        $args['meta_query'] = array('relation' => 'AND');

        if ($minimum_signature != 0) {
            array_push(
                $args['meta_query'], array(
                    'key'     => 'petition_sign',
                    'value'   => $minimum_signature,
                    'type'    => 'NUMERIC',
                    'compare' => '>='
                )
            );
        }

            array_push(
                $args['meta_query'], array(
                    'key'     => 'petition_status',
                    'value'   => '2',
                    'compare' => '!='
                )
            );

        $postslist = new WP_Query($args); ?>

        <?php
        if ( $postslist->have_posts() ) : ?>
            <div class="ui relaxed items">
            <?php while( $postslist->have_posts() ) : $postslist->the_post();
                
                /*
                 * Include the petition template for the content.
                 * If you want to override this in a child theme, then include a file
                 */
                get_template_part('loop/content-petition', 'widget');
                ?>
            <?php endwhile; ?>
            </div>
        <?php endif; ?>

        <?php 
        echo wp_kses_post($after_widget);
        wp_reset_postdata();
        wp_reset_query();
    }
}?>