<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
 * Submit Withdraw money
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_submit_withdraw') ):
    function conikal_submit_withdraw() {
        check_ajax_referer('withdraw_ajax_nonce', 'security');
        global $campoal_options;
        
        $minimum_paypal     = isset($campoal_options['conikal_minimum_withdrawal_paypal_field']) && $campoal_options['conikal_minimum_withdrawal_paypal_field'] != '' ? $campoal_options['conikal_minimum_withdrawal_paypal_field'] : 0;
        $minimum_payoneer   = isset($campoal_options['conikal_minimum_withdrawal_payoneer_field']) && $campoal_options['conikal_minimum_withdrawal_payoneer_field'] != '' ? $campoal_options['conikal_minimum_withdrawal_payoneer_field'] : 0;
        $minimum_bank       = isset($campoal_options['conikal_minimum_withdrawal_bank_field']) && $campoal_options['conikal_minimum_withdrawal_bank_field'] != '' ? $campoal_options['conikal_minimum_withdrawal_bank_field'] : 0;
        $minimum_bitcoin 	= isset($campoal_options['conikal_minimum_withdrawal_bitcoin_field']) && $campoal_options['conikal_minimum_withdrawal_bitcoin_field'] != '' ? $campoal_options['conikal_minimum_withdrawal_bitcoin_field'] : 0;

        $user_id            = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $amount             = isset($_POST['withdraw_amount']) ? sanitize_text_field($_POST['withdraw_amount']) : '';
        $type               = isset($_POST['withdraw_type']) ? sanitize_text_field($_POST['withdraw_type']) : '';
        $method             = isset($_POST['withdraw_method']) ? sanitize_text_field($_POST['withdraw_method']) : '';
        $confirm_password   = isset($_POST['confirm_password']) ? sanitize_text_field($_POST['confirm_password']) : '';
        $user_data          = get_userdata($user_id);
        $balance            = conikal_give_balance($user_id);

        if ($confirm_password === '' || !wp_check_password($confirm_password, $user_data->user_pass, $user_id)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The password do not match.', 'campoal-tapo')));
            exit();
        }

        if ($type === 'amount' && $amount === '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The amount of money are empty.', 'campoal-tapo')));
            exit();
        }

        if ($amount > $balance) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The withdrawal amount must not exceed the balance.', 'campoal-tapo')));
            exit();
        }

        if (!$method) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('You have not selected a payment method.', 'campoal-tapo')));
            exit();
        }

        if ($method == 'paypal') {
            if ($amount < $minimum_paypal) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('The withdrawal amount is less than the PayPal minimum.', 'campoal-tapo')));
                exit();
            }
        } elseif ($method == 'payoneer') {
            if ($amount < $minimum_payoneer) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('The withdrawal amount is less than the Payoneer minimum.', 'campoal-tapo')));
                exit();
            }
        } elseif ($method == 'bank') {
            if ($amount < $minimum_bank) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('The withdrawal amount is less than the Bank Transfer minimum.', 'campoal-tapo')));
                exit();
            }
        } elseif ($method == 'bitcoin') {
            if ($amount < $minimum_bitcoin) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('The withdrawal amount is less than the Bitcoin minimum.', 'campoal-tapo')));
                exit();
            }
        }

        // add new post type
        $withdrawal = array(
            'post_type' => 'withdraw',
            'post_status' => 'pending',
            'post_author' => $user_id,
        );

        $withdrawal_id = wp_insert_post($withdrawal);

        // update post meta
        if ($type === 'amount') {
            update_post_meta($withdrawal_id, 'withdraw_amount', $amount);
        } else {
            update_post_meta($withdrawal_id, 'withdraw_amount', $balance);
        }
        update_post_meta($withdrawal_id, 'withdraw_type', $type);
        update_post_meta($withdrawal_id, 'withdraw_method', $method);

        if($withdrawal_id != 0) {
            echo json_encode(array('status'=>true, 'message'=>esc_html__('The withdrawal request was submited successfully and pending for approval!', 'campoal-tapo')));
                exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=> esc_html__('Something went wrong. The withdrawal request was not submited!', 'campoal-tapo')));
            exit();
        }
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_submit_withdraw', 'conikal_submit_withdraw' );
add_action( 'wp_ajax_conikal_submit_withdraw', 'conikal_submit_withdraw' );


/**
 * Query all Withdrawals from user
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_all_withdrawls') ):
    function conikal_all_withdrawls($user_id, $posts_per_page = false) {
        if (!$posts_per_page) {
            global $campoal_options;
            
            $posts_per_page_setting = isset($campoal_options['conikal_petitions_per_page_field']) ? $campoal_options['conikal_petitions_per_page_field'] : '';
            $posts_per_page = $posts_per_page_setting != '' ? $posts_per_page_setting : 10;
        }

        global $paged;

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $args = array(
            'post_type' => 'withdraw',
            'posts_per_page' => $posts_per_page,
            'paged' => $paged,
            'post_status' => 'any',
            'author' => $user_id
        );

        $query = new WP_Query($args);

        wp_reset_query();
        wp_reset_postdata();
        
        return $query;
  }
endif;


/**
 * Get total amount withdraw by user id
 * 
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_total_withdraw') ):
    function conikal_total_withdraw($user_id) {
        
        $args = array(
            'post_type' => 'withdraw',
            'posts_per_page' => -1,
            'post_status' => array('publish'),
            'author' => $user_id
        );

        $withdrawals = new WP_Query($args);
        wp_reset_query();
        wp_reset_postdata();

        if ($withdrawals->have_posts()) {
            $total = 0;
            while( $withdrawals->have_posts() ) {
                $withdrawals->the_post();
                $withdraw_id = get_the_ID();
                $amount = get_post_meta($withdraw_id, 'withdraw_amount', true);
                if ($amount) {
                    $total = $total + $amount;
                }
            }
        } else {
            $total = 0;
        }

        return $total;
    }
endif;


/**
 * Change withdraw status label
 * 
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_get_withdraw_status') ): 
    function conikal_get_withdraw_status($post_id) {
        $status = get_post_status($post_id);
        $status_object = get_post_status_object($status);

        switch ($status) {
            case 'publish':
                $status_object->label = esc_html__('Completed', 'campoal-tapo');
                break;

            case 'draft':
                $status_object->label = esc_html__('Failed', 'campoal-tapo');
                break;

            case 'trash':
                $status_object->label = esc_html__('Canceled', 'campoal-tapo');
                break;
            
            default:
                # code...
                break;
        }

        return $status_object;
    }
endif;


/**
 * Withdraw label
 * 
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_withdraw_label') ):
    function conikal_withdraw_label($withdraw_id) {
        $type = get_post_meta($withdraw_id, 'withdraw_type', true);
        $method = get_post_meta($withdraw_id, 'withdraw_method', true);
        
        switch ($type) {
            case 'all':
                $type_label = esc_html__('All Balance', 'campoal-tapo');
                break;

            case 'amount':
                $type_label = esc_html__('Amount', 'campoal-tapo');
                break;
            
            default:
                $type_label = esc_html__('None', 'campoal-tapo');
                break;
        }

        switch ($method) {
            case 'paypal':
                $method_label = esc_html__('PayPal', 'campoal-tapo');
                break;

            case 'payoneer':
                $method_label = esc_html__('Payoneer', 'campoal-tapo');
                break;

            case 'bitcoin':
                $method_label = esc_html__('Bitcoin', 'campoal-tapo');
                break;

            case 'bank':
                $method_label = esc_html__('Bank Transfer', 'campoal-tapo');
                break;
            
            default:
                $method_label = esc_html__('None', 'campoal-tapo');
                break;
        }

        $label = (object) array(
            'type' => $type_label,
            'method' => $method_label
        );

        return $label;
    }
endif;

?>