<?php 

/*
/ Render category grid block in html
*/

if (!function_exists('conikal_category_grid_render')) {
    function conikal_category_grid_render($attrs, $content = null) {
        extract(shortcode_atts(array(
            'title'             => '',
            'title_alignment'   => 'center',
            'type'              => 'category',
            'show'              => 10,
            'orderby'           => 'name',
            'order'             => 'ASC',
            'categories'        => '',
            'topics'            => '',
            'exclude_selected'  => 0,
            'hide_empty'        => 0,
            'slugs'             => '',
        ), $attrs));

        global $campoal_options;
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;

        $slugs = explode(',', $slugs);

        $return_string = '';
        if (!empty($title)) {
            $return_string = '<div class="ui ' . esc_attr($title_alignment) . ' aligned vertical basic segment"><div class="ui huge header">' . esc_html($title) . '</div>';
            $return_string .= '<div class="title-divider"></div></div>';
        }
        $return_string .= '<div class="ui grid">';

        if ($type == 'category') {
            $taxonomy_name = 'petition_category';
            $term_meta_image = 'petition_category_image';
        } else if ($type == 'topics') {
            $taxonomy_name = 'petition_topics';
            $term_meta_image = 'petition_topics_image';
        } else {
            $taxonomy_name = array('petition_category', 'petition_topics');
            $term_meta_image = 'petition_' . $type . '_image';
        }


        // get terms data
        $args = array(
            'taxonomy'      => $taxonomy_name,
            'number'        => $show,
            'orderby'       => $orderby,
            'order'         => $order,
            'hide_empty'    => $hide_empty,
        );

        if ($type != 'by_id') {
            $term_ids = $type == 'category' ? $categories : $topics;
            if ($exclude_selected != 1) {
                $args['include'] = $term_ids;
            } else {
                $args['exclude'] = $term_ids;           
            }
        } else {
            $args['slug'] = $slugs;
        }
        
        $terms = get_terms($args);


        // Calcular grid column
        $col_count = 0;
        $total     = !empty($terms) ? count($terms) : $show;
        $spans     = array();

        for ( $i = 0; $i < $total; $i++ ) {
            $span = 4;

            if ( $i == 0 ) {
                $span = 8;
            } elseif( $i == $total - 1 ) {
                $span = 16 - $col_count;
            } elseif ( $i == rand(1, $total) ) {
                $span = 8;
            }

            $col_count = $col_count + $span;

            if ( $col_count > 16 ) {
                $span = 16 - $col_count + $span;
            }

            if ( $span < 4 ) {
                $spans[ $i - 1 ] = $spans[ $i - 1 ] - 1;
                $span = 4;
            }

            if ( $col_count >= 16 ) {
                $col_count = 0;
            }

            $spans[$i] = $span;
        }

        // Show term grid
        foreach ($terms as $key => $term) {

            /*
            $id_slug = str_replace(' ', '', $id_slug);
            $term = get_term_by('id', $id_slug, $taxonomy_name);
            if (!$term) {
                $term = get_term_by('slug', $id_slug, $taxonomy_name);
            }
            */

            if ($term) {
                // get post
                $args = array( 
                    'posts_per_page' => 1,
                    'paged' => 1,
                    'post_type' => 'petition',
                    'post_status' => 'publish'
                );

                $args['tax_query'] = array(
                    'relation' => 'OR',
                    array(
                        'taxonomy' => 'petition_topics',
                        'terms'    => $term->term_id,
                    )
                );
                
                $args['tag_id'] = $term->term_id;
                $args['meta_query'] = array('relation' => 'AND');

                if ($minimum_signature != 0) {
                    array_push($args['meta_query'], array(
                        'key'     => 'petition_sign',
                        'value'   => $minimum_signature,
                        'type'    => 'NUMERIC',
                        'compare' => '>='
                    ));
                }
                $postslist = new WP_Query( $args );
                
                if ( $postslist->have_posts() ) {
                    $post = $postslist->posts[0];
                }

                // get link
                $term_link  = get_term_link($term->term_id, $taxonomy_name);

                // get image cover
                $term_image = get_term_meta($term->term_id, $term_meta_image, true);

                if (empty($term_image)) {
                    if ( $postslist->have_posts() ) {
                        $term_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
                        if ($term_image) {
                            $term_image = $term_image ? $term_image[0] : '';
                        } else {
                            $term_image = get_template_directory_uri() . '/images/cover-card.svg';
                        }
                    } else {
                        $term_image = get_template_directory_uri() . '/images/cover-card.svg';
                    }
                }

                // return string
                $return_string .= '<div class="sixteen wide mobile eight wide tablet ' . convert_number_to_words($spans[$key]) . ' wide computer column">';
                $return_string .= '<a href="' . esc_url($term_link) . '" data-bjax>';
                $return_string .= '<div class="topic-card snip category">';
                $return_string .= '<img src="' . ($term_image ? esc_url($term_image) : '') . '" alt="' . $term->name . '"/>';
                $return_string .= '<div class="caption">';
                $return_string .= '<h3>' . $term->name . '</h3>';
                $return_string .= '</div>';
                $return_string .= '</div>';
                $return_string .= '</a>';
                $return_string .= '</div>';
            }
        }

        $return_string .= '</div>';

        return $return_string;
    }
}

?>